@@ -37,7 +37,7 @@ import java.io.Serializable;
  * Abstract attribute selection evaluation class
  *
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
- * @version $Revision: 5510 $
+ * @version $Revision: 11851 $
  */
 public abstract class ASEvaluation
   implements Serializable, CapabilitiesHandler, RevisionHandler {
@@ -137,9 +137,19 @@ public abstract class ASEvaluation
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5510 $");
+    return RevisionUtils.extract("$Revision: 11851 $");
   }
-  
+
+  /**
+   * Tells the evaluator that the attribute selection process is complete. It
+   * can then clean up data structures, references to training data as necessary
+   * in order to save memory
+   */
+  public void clean() {
+    // subclasses to override
+  }
+
+
   /**
    * runs the evaluator with the given commandline options
    * 
