@@ -89,7 +89,7 @@ import weka.filters.supervised.attribute.Discretize;
  * <!-- options-end -->
  * 
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
- * @version $Revision: 11219 $
+ * @version $Revision: 11851 $
  * @see Discretize
  */
 public class CfsSubsetEval
@@ -1110,7 +1110,6 @@ public class CfsSubsetEval
     int j = 0;
 
     if (!m_locallyPredictive) {
-      m_trainInstances = new Instances(m_trainInstances, 0);
       return attributeSet;
     }
 
@@ -1138,10 +1137,18 @@ public class CfsSubsetEval
       }
     }
 
-    m_trainInstances = new Instances(m_trainInstances, 0);
     return newSet;
   }
 
+  @Override
+  public void clean() {
+    if (m_trainInstances != null) {
+      // save memory
+      m_trainInstances = new Instances(m_trainInstances, 0);
+    }
+  }
+
+
   protected void resetOptions() {
     m_trainInstances = null;
     m_missingSeparate = false;
@@ -1156,7 +1163,7 @@ public class CfsSubsetEval
    */
   @Override
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 11219 $");
+    return RevisionUtils.extract("$Revision: 11851 $");
   }
 
   /**
