@@ -67,7 +67,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
- * @version $Revision: 5511 $
+ * @version $Revision: 11219 $
  */
 public class OneRAttributeEval
   extends ASEvaluation
@@ -467,8 +467,18 @@ public class OneRAttributeEval
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5511 $");
+    return RevisionUtils.extract("$Revision: 11219 $");
   }
+  
+  @Override
+  public int[] postProcess(int[] attributeSet) {
+
+    // save memory
+    m_trainInstances = new Instances(m_trainInstances, 0);
+
+    return attributeSet;
+  }
+
 
   // ============
   // Test method.
