@@ -108,7 +108,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
- * @version $Revision: 10424 $
+ * @version $Revision: 11851 $
  */
 public class WrapperSubsetEval
   extends ASEvaluation
@@ -675,8 +675,16 @@ public class WrapperSubsetEval
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 10424 $");
+    return RevisionUtils.extract("$Revision: 11851 $");
   }
+  
+  @Override
+  public void clean() {
+
+    // save memory
+    m_trainInstances = new Instances(m_trainInstances, 0);
+  }
+
 
   /**
    * Main method for testing this class.
