@@ -72,7 +72,7 @@ import weka.core.TechnicalInformation.Type;
  *
  * @author Andrew Golightly (acg4@cs.waikato.ac.nz)
  * @author Bernhard Pfahringer (bernhard@cs.waikato.ac.nz)
- * @version $Revision: 6303 $ 
+ * @version $Revision: 11303 $ 
  */
 public class NaiveBayesMultinomial 
   extends Classifier 
@@ -207,7 +207,7 @@ public class NaiveBayesMultinomial
 	for(int a = 0; a<instance.numValues(); a++)
 	  if(instance.index(a) != instance.classIndex())
 	    {
-	      if(!instance.isMissing(a))
+	      if(!instance.isMissingSparse(a))
 		{
 		  numOccurences = instance.valueSparse(a) * instance.weight();
 		  if(numOccurences < 0)
@@ -372,7 +372,7 @@ public class NaiveBayesMultinomial
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 6303 $");
+    return RevisionUtils.extract("$Revision: 11303 $");
   }
     
   /**
