@@ -143,7 +143,7 @@ import javax.swing.JTextField;
  <!-- options-end -->
  *
  * @author Malcolm Ware (mfw4@cs.waikato.ac.nz)
- * @version $Revision: 9445 $
+ * @version $Revision: 10073 $
  */
 public class MultilayerPerceptron 
   extends Classifier 
@@ -434,7 +434,7 @@ public class MultilayerPerceptron
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 9445 $");
+      return RevisionUtils.extract("$Revision: 10073 $");
     }
   }
   
@@ -685,14 +685,14 @@ public class MultilayerPerceptron
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 9445 $");
+      return RevisionUtils.extract("$Revision: 10073 $");
     }
   }
 
   /** 
    * This provides the basic controls for working with the neuralnetwork
    * @author Malcolm Ware (mfw4@cs.waikato.ac.nz)
-   * @version $Revision: 9445 $
+   * @version $Revision: 10073 $
    */
   class ControlPanel 
     extends JPanel
@@ -888,7 +888,7 @@ public class MultilayerPerceptron
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 9445 $");
+      return RevisionUtils.extract("$Revision: 10073 $");
     }
   }
   
@@ -2106,6 +2106,9 @@ public class MultilayerPerceptron
       m_currentInstance = i;
     }
     
+    // Make a copy of the instance so that it isn't modified
+    m_currentInstance = (Instance)m_currentInstance.copy();
+    
     if (m_normalizeAttributes) {
       for (int noa = 0; noa < m_instances.numAttributes(); noa++) {
 	if (noa != m_instances.classIndex()) {
@@ -2693,6 +2696,6 @@ public class MultilayerPerceptron
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 9445 $");
+    return RevisionUtils.extract("$Revision: 10073 $");
   }
 }
