@@ -156,7 +156,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author  Remco Bouckaert (remco@cs.waikato.ac.nz,rrb@xm.co.nz)
- * @version $Revision: 5439 $
+ * @version $Revision: 8126 $
  */
 public class SMOreg 
   extends Classifier 
@@ -522,11 +522,15 @@ public class SMOreg
     m_Missing = new ReplaceMissingValues();
     m_Missing.setInputFormat(instances);
     instances = Filter.useFilter(instances, m_Missing);
-    
-    if (!m_onlyNumeric) {
-      m_NominalToBinary = new NominalToBinary();
-      m_NominalToBinary.setInputFormat(instances);
-      instances = Filter.useFilter(instances, m_NominalToBinary);
+
+    if (getCapabilities().handles(Capability.NUMERIC_ATTRIBUTES)) {
+      if (!m_onlyNumeric) {
+        m_NominalToBinary = new NominalToBinary();
+        m_NominalToBinary.setInputFormat(instances);
+        instances = Filter.useFilter(instances, m_NominalToBinary);
+      } else {
+        m_NominalToBinary = null;
+      }
     } else {
       m_NominalToBinary = null;
     }
@@ -585,7 +589,7 @@ public class SMOreg
     m_Missing.batchFinished();
     instance = m_Missing.output();
     
-    if (!m_onlyNumeric) {
+    if (!m_onlyNumeric && m_NominalToBinary != null) {
       m_NominalToBinary.input(instance);
       m_NominalToBinary.batchFinished();
       instance = m_NominalToBinary.output();
@@ -762,9 +766,9 @@ public class SMOreg
    * @throws IllegalArgumentException if the named measure is not supported
    */
   public double getMeasure(String measureName) {
-    if (measureName.equals("measureKernelEvaluations"))
+    if (measureName.equalsIgnoreCase("measureKernelEvaluations"))
       return measureKernelEvaluations();
-    else if (measureName.equals("measureCacheHits"))
+    else if (measureName.equalsIgnoreCase("measureCacheHits"))
       return measureCacheHits();
     else
       throw new IllegalArgumentException("Measure '" +  measureName + "' is not supported!");
@@ -802,7 +806,7 @@ public class SMOreg
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5439 $");
+    return RevisionUtils.extract("$Revision: 8126 $");
   }
   
   /**
