@@ -31,7 +31,7 @@ import java.io.Serializable;
  * Abstract unit in a NeuralNetwork.
  *
  * @author Malcolm Ware (mfw4@cs.waikato.ac.nz)
- * @version $Revision: 1.7 $
+ * @version $Revision: 5403 $
  */
 public abstract class NeuralConnection
   implements Serializable, RevisionHandler {
@@ -182,6 +182,18 @@ public abstract class NeuralConnection
    * @return The error value, or NaN, if the value has not been calculated.
    */
   public abstract double errorValue(boolean calculate);
+  
+  /**
+   * Call this to have the connection save the current
+   * weights.
+   */
+  public abstract void saveWeights();
+  
+  /**
+   * Call this to have the connection restore from the saved
+   * weights.
+   */
+  public abstract void restoreWeights();
 
   /**
    * Call this to get the weight value on a particular connection.
