@@ -24,6 +24,7 @@ package weka.classifiers.functions.supportVector;
 
 import weka.core.Capabilities;
 import weka.core.CapabilitiesHandler;
+import weka.core.Copyable;
 import weka.core.Instance;
 import weka.core.Instances;
 import weka.core.Option;
@@ -44,7 +45,7 @@ import java.util.Vector;
  * 
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
  * @author FracPete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 5517 $
+ * @version $Revision: 9897 $
  */
 public abstract class Kernel 
   implements Serializable, OptionHandler, CapabilitiesHandler, RevisionHandler {
@@ -247,7 +248,7 @@ public abstract class Kernel
    * @return            the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5517 $");
+    return RevisionUtils.extract("$Revision: 9897 $");
   }
   
   /**
@@ -265,19 +266,23 @@ public abstract class Kernel
   }
 
   /**
-   * Creates a deep copy of the given kernel using serialization.
+   * Creates a shallow copy of the kernel (if it implements Copyable) 
+   * otherwise a deep copy using serialization.
    *
    * @param kernel 	the kernel to copy
-   * @return 		a deep copy of the kernel
+   * @return 		a shallow or deep copy of the kernel
    * @throws Exception 	if an error occurs
    */
   public static Kernel makeCopy(Kernel kernel) throws Exception {
+    if (kernel instanceof Copyable) {
+      return (Kernel) ((Copyable) kernel).copy();
+    }
     return (Kernel) new SerializedObject(kernel).getObject();
   }
 
   /**
-   * Creates a given number of deep copies of the given kernel using 
-   * serialization.
+   * Creates a given number of deep or shallow (if the kernel implements Copyable) 
+   * copies of the given kernel using serialization.
    * 
    * @param model 	the kernel to copy
    * @param num 	the number of kernel copies to create.
@@ -289,9 +294,15 @@ public abstract class Kernel
       throw new Exception("No model kernel set");
 
     Kernel[] kernels = new Kernel[num];
-    SerializedObject so = new SerializedObject(model);
-    for (int i = 0; i < kernels.length; i++)
-      kernels[i] = (Kernel) so.getObject();
+    if (model instanceof Copyable) {
+      for (int i = 0; i < kernels.length; i++) {
+        kernels[i] = (Kernel) ((Copyable) model).copy();
+      }
+    } else {
+      SerializedObject so = new SerializedObject(model);
+      for (int i = 0; i < kernels.length; i++)
+        kernels[i] = (Kernel) so.getObject();
+    }
 
     return kernels;
   }
