@@ -68,7 +68,7 @@ import java.util.Vector;
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
  * @author Shane Legg (shane@intelligenesis.net) (sparse vector code)
  * @author Stuart Inglis (stuart@reeltwo.com) (sparse vector code)
- * @version $Revision: 5808 $
+ * @version $Revision: 9993 $
  */
 public class PolyKernel 
   extends CachedKernel {
@@ -89,6 +89,17 @@ public class PolyKernel
     super();
   }
   
+  /**
+   * Frees the cache used by the kernel.
+   */
+  public void clean() {
+    if (getExponent() == 1.0) {
+      m_data = null;
+    }    
+    super.clean();
+  }
+
+  
   /**
    * Creates a new <code>PolyKernel</code> instance.
    * 
@@ -349,7 +360,7 @@ public class PolyKernel
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5808 $");
+    return RevisionUtils.extract("$Revision: 9993 $");
   }
 }
 
