@@ -110,7 +110,7 @@ import java.util.Vector;
  * @author Stuart Inglis (singlis@cs.waikato.ac.nz)
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
- * @version $Revision: 6573 $
+ * @version $Revision: 10069 $
  */
 public class IBk 
   extends Classifier 
@@ -385,8 +385,9 @@ public class IBk
    */
   public String crossValidateTipText() {
 
-    return "Whether hold-one-out cross-validation will be used " +
-      "to select the best k value.";
+    return "Whether hold-one-out cross-validation will be used to " +
+      "select the best k value between 1 and the value specified as " +
+      "the KNN parameter.";
   }
   
   /**
@@ -1055,7 +1056,7 @@ public class IBk
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 6573 $");
+    return RevisionUtils.extract("$Revision: 10069 $");
   }
   
   /**
