@@ -128,7 +128,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
- * @version $Revision: 5981 $ 
+ * @version $Revision: 12089 $ 
  */
 public class DecisionTable 
   extends Classifier 
@@ -1164,7 +1164,7 @@ public class DecisionTable
     // Replace the global table majority with nearest neighbour?
     if (m_useIBk) {
       m_ibk = new IBk();
-      m_ibk.buildClassifier(m_theInstances);
+      m_ibk.buildClassifier(m_dtInstances);
     }
 
     // Save memory
@@ -1396,7 +1396,7 @@ public class DecisionTable
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5981 $");
+    return RevisionUtils.extract("$Revision: 12089 $");
   }
 
   /**
