@@ -132,7 +132,7 @@ import java.util.Vector;
  *
  * @author Xin Xu (xx5@cs.waikato.ac.nz)
  * @author Eibe Frank (eibe@cs.waikato.ac.nz)
- * @version $Revision: 4608 $
+ * @version $Revision: 8119 $
  */
 public class JRip 
   extends Classifier 
@@ -668,7 +668,7 @@ public class JRip
    * the corresponding value.  There are two inherited classes, namely NumericAntd
    * and NominalAntd in which the attributes are numeric and nominal respectively.
    */    
-  private abstract class Antd 
+  public abstract class Antd 
     implements WeightedInstancesHandler, Copyable, Serializable, RevisionHandler {
 
     /** for serialization */
@@ -733,14 +733,14 @@ public class JRip
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 4608 $");
+      return RevisionUtils.extract("$Revision: 8119 $");
     }
   }
     
   /** 
    * The antecedent with numeric attribute
    */
-  private class 
+  public class 
     NumericAntd extends Antd {
     
     /** for serialization */
@@ -935,7 +935,7 @@ public class JRip
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 4608 $");
+      return RevisionUtils.extract("$Revision: 8119 $");
     }
   }
     
@@ -943,7 +943,7 @@ public class JRip
   /** 
    * The antecedent with nominal attribute
    */
-  private class NominalAntd 
+  public class NominalAntd 
     extends Antd {
 	
     /** for serialization */
@@ -1059,7 +1059,7 @@ public class JRip
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 4608 $");
+      return RevisionUtils.extract("$Revision: 8119 $");
     }
   }
 
@@ -1073,7 +1073,7 @@ public class JRip
    * select an antecedent and Reduced Error Prunning (REP) with the metric
    * of accuracy rate p/(p+n) or (TP+TN)/(P+N) is used to prune the rule. 
    */    
-  protected class RipperRule 
+  public class RipperRule 
     extends Rule {
     
     /** for serialization */
@@ -1152,6 +1152,15 @@ public class JRip
       else
 	return (m_Antds.size() > 0);
     }      
+    
+    /**
+     * Return the antecedents
+     * 
+     * @return the vector of antecedents
+     */
+    public FastVector getAntds() {
+      return m_Antds;
+    }
 	
     /** 
      * the number of antecedents of the rule
@@ -1422,7 +1431,7 @@ public class JRip
      * @return		the revision
      */
     public String getRevision() {
-      return RevisionUtils.extract("$Revision: 4608 $");
+      return RevisionUtils.extract("$Revision: 8119 $");
     }
   }
 
@@ -1433,6 +1442,7 @@ public class JRip
    */
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
+    result.disableAll();
 
     // attributes
     result.enable(Capability.NOMINAL_ATTRIBUTES);
@@ -2045,7 +2055,7 @@ public class JRip
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 4608 $");
+    return RevisionUtils.extract("$Revision: 8119 $");
   }
     
   /**
