@@ -37,15 +37,24 @@ import javax.swing.JOptionPane;
  */
 public class Memory implements RevisionHandler {
 
+  public static final long OUT_OF_MEMORY_THRESHOLD = 52428800L;
+
+  public static final long LOW_MEMORY_MINIMUM = 104857600L;
+
+  public static final long MAX_SLEEP_TIME = 10L;
+
   /** whether memory management is enabled */
   protected static boolean m_Enabled = true;
 
   /** whether a GUI is present */
   protected boolean m_UseGUI = false;
 
+  /** the delay before testing for out of memory */
+  protected long m_SleepTime = MAX_SLEEP_TIME;
+
   /** the managed bean to use */
   protected static MemoryMXBean m_MemoryMXBean = ManagementFactory
-      .getMemoryMXBean();
+    .getMemoryMXBean();
 
   /** the last MemoryUsage object obtained */
   protected MemoryUsage m_MemoryUsage = null;
@@ -137,11 +146,30 @@ public class Memory implements RevisionHandler {
    *         false)
    */
   public boolean isOutOfMemory() {
+    try {
+      Thread.sleep(m_SleepTime);
+    } catch (InterruptedException ex) {
+      ex.printStackTrace();
+    }
+
     m_MemoryUsage = m_MemoryMXBean.getHeapMemoryUsage();
     if (isEnabled()) {
-      return ((m_MemoryUsage.getMax() - m_MemoryUsage.getUsed()) < 52428800);
-    } else
+
+      long avail = m_MemoryUsage.getMax() - m_MemoryUsage.getUsed();
+      if (avail > OUT_OF_MEMORY_THRESHOLD) {
+        long num = (avail - OUT_OF_MEMORY_THRESHOLD) / 5242880 + 1;
+
+        m_SleepTime = (long) (2.0 * (Math.log(num) + 2.5));
+        if (m_SleepTime > MAX_SLEEP_TIME) {
+          m_SleepTime = MAX_SLEEP_TIME;
+        }
+        // System.out.println("Delay = " + m_SleepTime);
+      }
+
+      return avail < OUT_OF_MEMORY_THRESHOLD;
+    } else {
       return false;
+    }
   }
 
   /**
@@ -157,8 +185,8 @@ public class Memory implements RevisionHandler {
       long lowThreshold = (long) (0.2 * m_MemoryUsage.getMax());
 
       // min threshold of 100Mb
-      if (lowThreshold < 104857600) {
-        lowThreshold = 104857600;
+      if (lowThreshold < LOW_MEMORY_MINIMUM) {
+        lowThreshold = LOW_MEMORY_MINIMUM;
       }
 
       long avail = m_MemoryUsage.getMax() - m_MemoryUsage.getUsed();
@@ -187,36 +215,38 @@ public class Memory implements RevisionHandler {
    * @see #m_Enabled
    */
   public void showOutOfMemory() {
-    if (!isEnabled() || (m_MemoryUsage == null))
+    if (!isEnabled() || (m_MemoryUsage == null)) {
       return;
+    }
 
     System.gc();
 
     String msg = "Not enough memory (less than 50MB left on heap). Please load a smaller "
-        + "dataset or use a larger heap size.\n"
-        + "- initial heap size:   "
-        + Utils.doubleToString(toMegaByte(m_MemoryUsage.getInit()), 1)
-        + "MB\n"
-        + "- current memory (heap) used:  "
-        + Utils.doubleToString(toMegaByte(m_MemoryUsage.getUsed()), 1)
-        + "MB\n"
-        + "- max. memory (heap) available: "
-        + Utils.doubleToString(toMegaByte(m_MemoryUsage.getMax()), 1)
-        + "MB\n"
-        + "\n"
-        + "Note:\n"
-        + "The Java heap size can be specified with the -Xmx option.\n"
-        + "E.g., to use 128MB as heap size, the command line looks like this:\n"
-        + "   java -Xmx128m -classpath ...\n"
-        + "This does NOT work in the SimpleCLI, the above java command refers\n"
-        + "to the one with which Weka is started. See the Weka FAQ on the web\n"
-        + "for further info.";
+      + "dataset or use a larger heap size.\n"
+      + "- initial heap size:   "
+      + Utils.doubleToString(toMegaByte(m_MemoryUsage.getInit()), 1)
+      + "MB\n"
+      + "- current memory (heap) used:  "
+      + Utils.doubleToString(toMegaByte(m_MemoryUsage.getUsed()), 1)
+      + "MB\n"
+      + "- max. memory (heap) available: "
+      + Utils.doubleToString(toMegaByte(m_MemoryUsage.getMax()), 1)
+      + "MB\n"
+      + "\n"
+      + "Note:\n"
+      + "The Java heap size can be specified with the -Xmx option.\n"
+      + "E.g., to use 128MB as heap size, the command line looks like this:\n"
+      + "   java -Xmx128m -classpath ...\n"
+      + "This does NOT work in the SimpleCLI, the above java command refers\n"
+      + "to the one with which Weka is started. See the Weka FAQ on the web\n"
+      + "for further info.";
 
     System.err.println(msg);
 
-    if (getUseGUI())
+    if (getUseGUI()) {
       JOptionPane.showMessageDialog(null, msg, "OutOfMemory",
-          JOptionPane.WARNING_MESSAGE);
+        JOptionPane.WARNING_MESSAGE);
+    }
   }
 
   /**
@@ -225,30 +255,31 @@ public class Memory implements RevisionHandler {
    * @return true if user opts to continue, disabled or GUI is not present.
    */
   public boolean showMemoryIsLow() {
-    if (!isEnabled() || (m_MemoryUsage == null))
+    if (!isEnabled() || (m_MemoryUsage == null)) {
       return true;
+    }
 
     String msg = "Warning: memory is running low - available heap space is less than "
-        + "20% of maximum or 100MB (whichever is greater)\n\n"
-        + "- initial heap size:   "
-        + Utils.doubleToString(toMegaByte(m_MemoryUsage.getInit()), 1)
-        + "MB\n"
-        + "- current memory (heap) used:  "
-        + Utils.doubleToString(toMegaByte(m_MemoryUsage.getUsed()), 1)
-        + "MB\n"
-        + "- max. memory (heap) available: "
-        + Utils.doubleToString(toMegaByte(m_MemoryUsage.getMax()), 1)
-        + "MB\n\n"
-        + "Consider deleting some results before continuing.\nCheck the Weka FAQ "
-        + "on the web for suggestions on how to save memory.\n"
-        + "Note that Weka will shut down when less than 50MB remain."
-        + "\nDo you wish to continue regardless?\n\n";
+      + "20% of maximum or 100MB (whichever is greater)\n\n"
+      + "- initial heap size:   "
+      + Utils.doubleToString(toMegaByte(m_MemoryUsage.getInit()), 1)
+      + "MB\n"
+      + "- current memory (heap) used:  "
+      + Utils.doubleToString(toMegaByte(m_MemoryUsage.getUsed()), 1)
+      + "MB\n"
+      + "- max. memory (heap) available: "
+      + Utils.doubleToString(toMegaByte(m_MemoryUsage.getMax()), 1)
+      + "MB\n\n"
+      + "Consider deleting some results before continuing.\nCheck the Weka FAQ "
+      + "on the web for suggestions on how to save memory.\n"
+      + "Note that Weka will shut down when less than 50MB remain."
+      + "\nDo you wish to continue regardless?\n\n";
 
     System.err.println(msg);
 
     if (getUseGUI()) {
       int result = JOptionPane.showConfirmDialog(null, msg, "Low Memory",
-          JOptionPane.YES_NO_OPTION);
+        JOptionPane.YES_NO_OPTION);
 
       return (result == JOptionPane.YES_OPTION);
     }
@@ -271,10 +302,11 @@ public class Memory implements RevisionHandler {
       t = thGroup[i];
       if (t != null) {
         if (t != Thread.currentThread()) {
-          if (t.getName().startsWith("Thread"))
+          if (t.getName().startsWith("Thread")) {
             t.stop();
-          else if (t.getName().startsWith("AWT-EventQueue"))
+          } else if (t.getName().startsWith("AWT-EventQueue")) {
             t.stop();
+          }
         }
       }
     }
@@ -289,6 +321,7 @@ public class Memory implements RevisionHandler {
    * 
    * @return the revision
    */
+  @Override
   public String getRevision() {
     return RevisionUtils.extract("$Revision: 9487 $");
   }
@@ -301,10 +334,10 @@ public class Memory implements RevisionHandler {
   public static void main(String[] args) {
     Memory mem = new Memory();
     System.out.println("Initial memory: "
-        + Utils.doubleToString(Memory.toMegaByte(mem.getInitial()), 1) + "MB"
-        + " (" + mem.getInitial() + ")");
+      + Utils.doubleToString(Memory.toMegaByte(mem.getInitial()), 1) + "MB"
+      + " (" + mem.getInitial() + ")");
     System.out.println("Max memory: "
-        + Utils.doubleToString(Memory.toMegaByte(mem.getMax()), 1) + "MB"
-        + " (" + mem.getMax() + ")");
+      + Utils.doubleToString(Memory.toMegaByte(mem.getMax()), 1) + "MB" + " ("
+      + mem.getMax() + ")");
   }
 }
