@@ -25,6 +25,7 @@ import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
+import java.io.IOException;
 import java.io.InputStream;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
@@ -39,7 +40,7 @@ import java.util.Vector;
  * objects to and fro files or streams.
  * 
  * @author  fracpete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 6229 $
+ * @version $Revision: 8597 $
  */
 public class SerializationHelper
   implements RevisionHandler {
@@ -323,7 +324,7 @@ public class SerializationHelper
 	result.add(ois.readObject());
       }
     }
-    catch (Exception e) {
+    catch (IOException e) {
       // ignored
     }
     ois.close();
@@ -337,7 +338,7 @@ public class SerializationHelper
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 6229 $");
+    return RevisionUtils.extract("$Revision: 8597 $");
   }
   
   /**
