@@ -114,7 +114,7 @@ import java.util.Vector;
  <!-- options-end -->
  * 
  * @author FracPete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 1.10 $
+ * @version $Revision: 6325 $
  * @see weka.classifiers.CheckClassifier
  */
 public class TestInstances 
@@ -1286,7 +1286,8 @@ public class TestInstances
    * @see #CLASS_IS_LAST
    * @see #NO_CLASS
    */
-  protected Attribute generateAttribute(int index, int attType) throws Exception {
+  protected Attribute generateAttribute(int index, int attType,
+      String namePrefix) throws Exception {
     Attribute     result;
     String        name;
     int           valIndex;
@@ -1338,19 +1339,19 @@ public class TestInstances
         FastVector nomStrings = new FastVector(valIndex + 1);
         for (int j = 0; j < nomCount; j++)
           nomStrings.addElement(prefix + (j + 1));
-        result = new Attribute(name, nomStrings);
+        result = new Attribute(namePrefix + name, nomStrings);
         break;
         
       case Attribute.NUMERIC:
-        result = new Attribute(name);
+        result = new Attribute(namePrefix + name);
         break;
         
       case Attribute.STRING:
-        result = new Attribute(name, (FastVector) null);
+        result = new Attribute(namePrefix + name, (FastVector) null);
         break;
         
       case Attribute.DATE:
-        result = new Attribute(name, "yyyy-mm-dd");
+        result = new Attribute(namePrefix + name, "yyyy-mm-dd");
         break;
         
       case Attribute.RELATIONAL:
@@ -1376,7 +1377,7 @@ public class TestInstances
             rel.deleteAttributeAt(clsIndex);
           }
         }
-        result = new Attribute(name, rel);
+        result = new Attribute(namePrefix + name, rel);
         break;
         
       default:
@@ -1508,19 +1509,30 @@ public class TestInstances
     return result;
   }
   
+  /**
+   * Generates a new dataset
+   * 
+   * @return the generated data
+   * @throws Exception if something goes wrong
+   */
+  public Instances generate() throws Exception {
+    return generate("");
+  }
+  
   /**
    * generates a new dataset.
    * 
+   * @param namePrefix the prefix to add to the name of an attribute
    * @return 		the generated data
    * @throws Exception	if something goes wrong
    */
-  public Instances generate() throws Exception {
+  public Instances generate(String namePrefix) throws Exception {
     if (getMultiInstance()) {
       TestInstances bag = (TestInstances) this.clone();
       bag.setMultiInstance(false);
       bag.setNumInstances(0);
       bag.setSeed(m_Random.nextInt());
-      Instances bagFormat = bag.generate();
+      Instances bagFormat = bag.generate("bagAtt_");
       bagFormat.setClassIndex(-1);
       bagFormat.deleteAttributeAt(bagFormat.numAttributes() - 1);
 
@@ -1540,7 +1552,7 @@ public class TestInstances
       bag.setNumInstances(getNumInstancesRelational());
       for (int i = 0; i < getNumInstances(); i++) {
         bag.setSeed(m_Random.nextInt());
-        Instances bagData = new Instances(bag.generate());
+        Instances bagData = new Instances(bag.generate("bagAtt_"));
         bagData.setClassIndex(-1);
         bagData.deleteAttributeAt(bagData.numAttributes() - 1);
         double val = m_Data.attribute(1).addRelation(bagData);
@@ -1557,27 +1569,27 @@ public class TestInstances
       FastVector attributes = new FastVector(getNumAttributes());
       // Add Nominal attributes
       for (int i = 0; i < getNumNominal(); i++)
-        attributes.addElement(generateAttribute(i, Attribute.NOMINAL));
+        attributes.addElement(generateAttribute(i, Attribute.NOMINAL, namePrefix));
       
       // Add m_Numeric attributes
       for (int i = 0; i < getNumNumeric(); i++)
-        attributes.addElement(generateAttribute(i, Attribute.NUMERIC));
+        attributes.addElement(generateAttribute(i, Attribute.NUMERIC, namePrefix));
       
       // Add some String attributes...
       for (int i = 0; i < getNumString(); i++)
-        attributes.addElement(generateAttribute(i, Attribute.STRING));
+        attributes.addElement(generateAttribute(i, Attribute.STRING, namePrefix));
       
       // Add some Date attributes...
       for (int i = 0; i < getNumDate(); i++)
-        attributes.addElement(generateAttribute(i, Attribute.DATE));
+        attributes.addElement(generateAttribute(i, Attribute.DATE, namePrefix));
       
       // Add some Relational attributes...
       for (int i = 0; i < getNumRelational(); i++)
-        attributes.addElement(generateAttribute(i, Attribute.RELATIONAL));
+        attributes.addElement(generateAttribute(i, Attribute.RELATIONAL, namePrefix));
       
       // Add class attribute
       if (clsIndex != NO_CLASS)
-	attributes.insertElementAt(generateAttribute(CLASS_IS_LAST, getClassType()), clsIndex);
+	attributes.insertElementAt(generateAttribute(CLASS_IS_LAST, getClassType(), namePrefix), clsIndex);
       
       m_Data = new Instances(getRelation(), attributes, getNumInstances());
       m_Data.setClassIndex(clsIndex);
@@ -1745,7 +1757,7 @@ public class TestInstances
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.10 $");
+    return RevisionUtils.extract("$Revision: 6325 $");
   }
   
   /**
