@@ -20,13 +20,15 @@
  *
  */
 
-
 package weka.experiment;
 
-import weka.clusterers.ClusterEvaluation;
-import weka.clusterers.Clusterer;
+import java.io.ObjectStreamClass;
+import java.io.Serializable;
+import java.util.Enumeration;
+import java.util.Vector;
+
 import weka.clusterers.AbstractClusterer;
-import weka.clusterers.AbstractDensityBasedClusterer;
+import weka.clusterers.ClusterEvaluation;
 import weka.clusterers.DensityBasedClusterer;
 import weka.clusterers.EM;
 import weka.core.AdditionalMeasureProducer;
@@ -39,26 +41,22 @@ import weka.core.Utils;
 import weka.filters.Filter;
 import weka.filters.unsupervised.attribute.Remove;
 
-import java.io.ObjectStreamClass;
-import java.io.Serializable;
-import java.util.Enumeration;
-import java.util.Vector;
-
 /**
  * A SplitEvaluator that produces results for a density based clusterer.
- *
+ * 
  * -W classname <br>
- * Specify the full class name of the clusterer to evaluate. <p>
- *
+ * Specify the full class name of the clusterer to evaluate.
+ * <p>
+ * 
  * @author Mark Hall (mhall{[at]}pentaho{[dot]}org
- * @version $Revision: 5562 $
+ * @version $Revision: 11198 $
  */
 
-public class DensityBasedClustererSplitEvaluator 
+public class DensityBasedClustererSplitEvaluator
   implements SplitEvaluator,
-	     OptionHandler,
-	     AdditionalMeasureProducer,
-	     RevisionHandler {
+  OptionHandler,
+  AdditionalMeasureProducer,
+  RevisionHandler {
 
   /** Remove the class column (if set) from the data */
   protected boolean m_removeClassColumn = true;
@@ -67,16 +65,20 @@ public class DensityBasedClustererSplitEvaluator
   protected DensityBasedClusterer m_clusterer = new EM();
 
   /** The names of any additional measures to look for in SplitEvaluators */
-  protected String [] m_additionalMeasures = null;
+  protected String[] m_additionalMeasures = null;
 
-  /** Array of booleans corresponding to the measures in m_AdditionalMeasures
-      indicating which of the AdditionalMeasures the current clusterer
-      can produce */
-  protected boolean [] m_doesProduce = null;
+  /**
+   * Array of booleans corresponding to the measures in m_AdditionalMeasures
+   * indicating which of the AdditionalMeasures the current clusterer can
+   * produce
+   */
+  protected boolean[] m_doesProduce = null;
 
-  /** The number of additional measures that need to be filled in
-      after taking into account column constraints imposed by the final
-      destination for results */
+  /**
+   * The number of additional measures that need to be filled in after taking
+   * into account column constraints imposed by the final destination for
+   * results
+   */
   protected int m_numberAdditionalMeasures = 0;
 
   /** Holds the statistics for the most recent application of the clusterer */
@@ -94,15 +96,15 @@ public class DensityBasedClustererSplitEvaluator
   /** The length of a result */
   private static final int RESULT_SIZE = 6;
 
-  
   public DensityBasedClustererSplitEvaluator() {
     updateOptions();
   }
 
   /**
    * Returns a string describing this split evaluator
-   * @return a description of the split evaluator suitable for
-   * displaying in the explorer/experimenter gui
+   * 
+   * @return a description of the split evaluator suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String globalInfo() {
     return " A SplitEvaluator that produces results for a density based clusterer. ";
@@ -110,76 +112,81 @@ public class DensityBasedClustererSplitEvaluator
 
   /**
    * Returns an enumeration describing the available options.
-   *
+   * 
    * @return an enumeration of all the available options.
    */
+  @Override
   public Enumeration listOptions() {
 
     Vector newVector = new Vector(1);
 
     newVector.addElement(new Option(
-				    "\tThe full class name of the density based clusterer.\n"
-				    +"\teg: weka.clusterers.EM", 
-				    "W", 1, 
-				    "-W <class name>"));
+      "\tThe full class name of the density based clusterer.\n"
+        + "\teg: weka.clusterers.EM",
+      "W", 1,
+      "-W <class name>"));
 
     if ((m_clusterer != null) &&
-	(m_clusterer instanceof OptionHandler)) {
+      (m_clusterer instanceof OptionHandler)) {
       newVector.addElement(new Option(
-				      "",
-				      "", 0, "\nOptions specific to clusterer "
-				      + m_clusterer.getClass().getName() + ":"));
-      Enumeration enu = ((OptionHandler)m_clusterer).listOptions();
+        "",
+        "", 0, "\nOptions specific to clusterer "
+          + m_clusterer.getClass().getName() + ":"));
+      Enumeration enu = ((OptionHandler) m_clusterer).listOptions();
       while (enu.hasMoreElements()) {
-	newVector.addElement(enu.nextElement());
+        newVector.addElement(enu.nextElement());
       }
     }
     return newVector.elements();
   }
 
   /**
-   * Parses a given list of options. Valid options are:<p>
-   *
+   * Parses a given list of options. Valid options are:
+   * <p>
+   * 
    * -W classname <br>
-   * Specify the full class name of the clusterer to evaluate. <p>
-   *
+   * Specify the full class name of the clusterer to evaluate.
+   * <p>
+   * 
    * All option after -- will be passed to the classifier.
-   *
+   * 
    * @param options the list of options as an array of strings
    * @exception Exception if an option is not supported
    */
+  @Override
   public void setOptions(String[] options) throws Exception {
-    
+
     String cName = Utils.getOption('W', options);
-    if (cName.length() == 0) {
-      throw new Exception("A clusterer must be specified with"
-			  + " the -W option.");
+    if (cName.length() > 0) {
+
+      // Do it first without options, so if an exception is thrown during
+      // the option setting, listOptions will contain options for the actual
+      // Classifier.
+      setClusterer((DensityBasedClusterer) AbstractClusterer.forName(cName,
+        null));
     }
-    // Do it first without options, so if an exception is thrown during
-    // the option setting, listOptions will contain options for the actual
-    // Classifier.
-    setClusterer((DensityBasedClusterer)AbstractClusterer.forName(cName, null));
     if (getClusterer() instanceof OptionHandler) {
       ((OptionHandler) getClusterer())
-	.setOptions(Utils.partitionOptions(options));
+        .setOptions(Utils.partitionOptions(options));
       updateOptions();
     }
   }
 
   /**
    * Gets the current settings of the Classifier.
-   *
+   * 
    * @return an array of strings suitable for passing to setOptions
    */
-  public String [] getOptions() {
+  @Override
+  public String[] getOptions() {
 
-    String [] clustererOptions = new String [0];
-    if ((m_clusterer != null) && 
-	(m_clusterer instanceof OptionHandler)) {
-      clustererOptions = ((OptionHandler)m_clusterer).getOptions();
+    String[] clustererOptions = new String[0];
+    if ((m_clusterer != null) &&
+      (m_clusterer instanceof OptionHandler)) {
+      clustererOptions = ((OptionHandler) m_clusterer).getOptions();
     }
-    
-    String [] options = new String [clustererOptions.length + 3];
+
+    String[] options = new String[clustererOptions.length + 3];
     int current = 0;
 
     if (getClusterer() != null) {
@@ -189,8 +196,8 @@ public class DensityBasedClustererSplitEvaluator
 
     options[current++] = "--";
 
-    System.arraycopy(clustererOptions, 0, options, current, 
-		     clustererOptions.length);
+    System.arraycopy(clustererOptions, 0, options, current,
+      clustererOptions.length);
     current += clustererOptions.length;
     while (current < options.length) {
       options[current++] = "";
@@ -199,32 +206,34 @@ public class DensityBasedClustererSplitEvaluator
   }
 
   /**
-   * Set a list of method names for additional measures to look for
-   * in Classifiers. This could contain many measures (of which only a
-   * subset may be produceable by the current Classifier) if an experiment
-   * is the type that iterates over a set of properties.
+   * Set a list of method names for additional measures to look for in
+   * Classifiers. This could contain many measures (of which only a subset may
+   * be produceable by the current Classifier) if an experiment is the type that
+   * iterates over a set of properties.
+   * 
    * @param additionalMeasures a list of method names
    */
-  public void setAdditionalMeasures(String [] additionalMeasures) {
+  @Override
+  public void setAdditionalMeasures(String[] additionalMeasures) {
     // System.err.println("ClassifierSplitEvaluator: setting additional measures");
     m_additionalMeasures = additionalMeasures;
-    
+
     // determine which (if any) of the additional measures this clusterer
     // can produce
     if (m_additionalMeasures != null && m_additionalMeasures.length > 0) {
-      m_doesProduce = new boolean [m_additionalMeasures.length];
+      m_doesProduce = new boolean[m_additionalMeasures.length];
 
       if (m_clusterer instanceof AdditionalMeasureProducer) {
-	Enumeration en = ((AdditionalMeasureProducer)m_clusterer).
-	  enumerateMeasures();
-	while (en.hasMoreElements()) {
-	  String mname = (String)en.nextElement();
-	  for (int j=0;j<m_additionalMeasures.length;j++) {
-	    if (mname.compareToIgnoreCase(m_additionalMeasures[j]) == 0) {
-	      m_doesProduce[j] = true;
-	    }
-	  }
-	}
+        Enumeration en = ((AdditionalMeasureProducer) m_clusterer).
+          enumerateMeasures();
+        while (en.hasMoreElements()) {
+          String mname = (String) en.nextElement();
+          for (int j = 0; j < m_additionalMeasures.length; j++) {
+            if (mname.compareToIgnoreCase(m_additionalMeasures[j]) == 0) {
+              m_doesProduce[j] = true;
+            }
+          }
+        }
       }
     } else {
       m_doesProduce = null;
@@ -232,18 +241,20 @@ public class DensityBasedClustererSplitEvaluator
   }
 
   /**
-   * Returns an enumeration of any additional measure names that might be
-   * in the classifier
+   * Returns an enumeration of any additional measure names that might be in the
+   * classifier
+   * 
    * @return an enumeration of the measure names
    */
+  @Override
   public Enumeration enumerateMeasures() {
     Vector newVector = new Vector();
     if (m_clusterer instanceof AdditionalMeasureProducer) {
-      Enumeration en = ((AdditionalMeasureProducer)m_clusterer).
-	enumerateMeasures();
+      Enumeration en = ((AdditionalMeasureProducer) m_clusterer).
+        enumerateMeasures();
       while (en.hasMoreElements()) {
-	String mname = (String)en.nextElement();
-	newVector.addElement(mname);
+        String mname = (String) en.nextElement();
+        newVector.addElement(mname);
       }
     }
     return newVector.elements();
@@ -251,33 +262,36 @@ public class DensityBasedClustererSplitEvaluator
 
   /**
    * Returns the value of the named measure
+   * 
    * @param measureName the name of the measure to query for its value
    * @return the value of the named measure
    * @exception IllegalArgumentException if the named measure is not supported
    */
+  @Override
   public double getMeasure(String additionalMeasureName) {
     if (m_clusterer instanceof AdditionalMeasureProducer) {
-      return ((AdditionalMeasureProducer)m_clusterer).
-	getMeasure(additionalMeasureName);
+      return ((AdditionalMeasureProducer) m_clusterer).
+        getMeasure(additionalMeasureName);
     } else {
-      throw new IllegalArgumentException("DensityBasedClustererSplitEvaluator: "
-					 +"Can't return value for : "+additionalMeasureName
-					 +". "+m_clusterer.getClass().getName()+" "
-					 +"is not an AdditionalMeasureProducer");
+      throw new IllegalArgumentException(
+        "DensityBasedClustererSplitEvaluator: "
+          + "Can't return value for : " + additionalMeasureName
+          + ". " + m_clusterer.getClass().getName() + " "
+          + "is not an AdditionalMeasureProducer");
     }
   }
 
   /**
    * Gets the data types of each of the key columns produced for a single run.
-   * The number of key fields must be constant
-   * for a given SplitEvaluator.
-   *
-   * @return an array containing objects of the type of each key column. The 
-   * objects should be Strings, or Doubles.
+   * The number of key fields must be constant for a given SplitEvaluator.
+   * 
+   * @return an array containing objects of the type of each key column. The
+   *         objects should be Strings, or Doubles.
    */
-  public Object [] getKeyTypes() {
+  @Override
+  public Object[] getKeyTypes() {
 
-    Object [] keyTypes = new Object[KEY_SIZE];
+    Object[] keyTypes = new Object[KEY_SIZE];
     keyTypes[0] = "";
     keyTypes[1] = "";
     keyTypes[2] = "";
@@ -285,15 +299,15 @@ public class DensityBasedClustererSplitEvaluator
   }
 
   /**
-   * Gets the names of each of the key columns produced for a single run.
-   * The number of key fields must be constant
-   * for a given SplitEvaluator.
-   *
+   * Gets the names of each of the key columns produced for a single run. The
+   * number of key fields must be constant for a given SplitEvaluator.
+   * 
    * @return an array containing the name of each key column
    */
-  public String [] getKeyNames() {
+  @Override
+  public String[] getKeyNames() {
 
-    String [] keyNames = new String[KEY_SIZE];
+    String[] keyNames = new String[KEY_SIZE];
     keyNames[0] = "Scheme";
     keyNames[1] = "Scheme_options";
     keyNames[2] = "Scheme_version_ID";
@@ -301,16 +315,17 @@ public class DensityBasedClustererSplitEvaluator
   }
 
   /**
-   * Gets the key describing the current SplitEvaluator. For example
-   * This may contain the name of the classifier used for classifier
-   * predictive evaluation. The number of key fields must be constant
-   * for a given SplitEvaluator.
-   *
+   * Gets the key describing the current SplitEvaluator. For example This may
+   * contain the name of the classifier used for classifier predictive
+   * evaluation. The number of key fields must be constant for a given
+   * SplitEvaluator.
+   * 
    * @return an array of objects containing the key.
    */
-  public Object [] getKey(){
+  @Override
+  public Object[] getKey() {
 
-    Object [] key = new Object[KEY_SIZE];
+    Object[] key = new Object[KEY_SIZE];
     key[0] = m_clusterer.getClass().getName();
     key[1] = m_clustererOptions;
     key[2] = m_clustererVersion;
@@ -318,27 +333,28 @@ public class DensityBasedClustererSplitEvaluator
   }
 
   /**
-   * Gets the data types of each of the result columns produced for a 
-   * single run. The number of result fields must be constant
-   * for a given SplitEvaluator.
-   *
-   * @return an array containing objects of the type of each result column. 
-   * The objects should be Strings, or Doubles.
+   * Gets the data types of each of the result columns produced for a single
+   * run. The number of result fields must be constant for a given
+   * SplitEvaluator.
+   * 
+   * @return an array containing objects of the type of each result column. The
+   *         objects should be Strings, or Doubles.
    */
-  public Object [] getResultTypes() {
-    int addm = (m_additionalMeasures != null) 
-      ? m_additionalMeasures.length 
+  @Override
+  public Object[] getResultTypes() {
+    int addm = (m_additionalMeasures != null)
+      ? m_additionalMeasures.length
       : 0;
-    int overall_length = RESULT_SIZE+addm;
+    int overall_length = RESULT_SIZE + addm;
 
-    Object [] resultTypes = new Object[overall_length];
+    Object[] resultTypes = new Object[overall_length];
     Double doub = new Double(0);
     int current = 0;
-    
+
     // number of training and testing instances
     resultTypes[current++] = doub;
     resultTypes[current++] = doub;
-    
+
     // log liklihood
     resultTypes[current++] = doub;
     // number of clusters
@@ -348,11 +364,10 @@ public class DensityBasedClustererSplitEvaluator
     resultTypes[current++] = doub;
     resultTypes[current++] = doub;
 
-
-    //    resultTypes[current++] = "";
+    // resultTypes[current++] = "";
 
     // add any additional measures
-    for (int i=0;i<addm;i++) {
+    for (int i = 0; i < addm; i++) {
       resultTypes[current++] = doub;
     }
     if (current != overall_length) {
@@ -362,19 +377,19 @@ public class DensityBasedClustererSplitEvaluator
   }
 
   /**
-   * Gets the names of each of the result columns produced for a single run.
-   * The number of result fields must be constant
-   * for a given SplitEvaluator.
-   *
+   * Gets the names of each of the result columns produced for a single run. The
+   * number of result fields must be constant for a given SplitEvaluator.
+   * 
    * @return an array containing the name of each result column
    */
-  public String [] getResultNames() {
-    int addm = (m_additionalMeasures != null) 
-      ? m_additionalMeasures.length 
+  @Override
+  public String[] getResultNames() {
+    int addm = (m_additionalMeasures != null)
+      ? m_additionalMeasures.length
       : 0;
-    int overall_length = RESULT_SIZE+addm;
-   
-    String [] resultNames = new String[overall_length];
+    int overall_length = RESULT_SIZE + addm;
+
+    String[] resultNames = new String[overall_length];
     int current = 0;
     resultNames[current++] = "Number_of_training_instances";
     resultNames[current++] = "Number_of_testing_instances";
@@ -388,9 +403,9 @@ public class DensityBasedClustererSplitEvaluator
     resultNames[current++] = "Time_testing";
 
     // Classifier defined extras
-    //    resultNames[current++] = "Summary";
+    // resultNames[current++] = "Summary";
     // add any additional measures
-    for (int i=0;i<addm;i++) {
+    for (int i = 0; i < addm; i++) {
       resultNames[current++] = m_additionalMeasures[i];
     }
     if (current != overall_length) {
@@ -401,41 +416,41 @@ public class DensityBasedClustererSplitEvaluator
 
   /**
    * Gets the results for the supplied train and test datasets.
-   *
+   * 
    * @param train the training Instances.
    * @param test the testing Instances.
-   * @return the results stored in an array. The objects stored in
-   * the array may be Strings, Doubles, or null (for the missing value).
+   * @return the results stored in an array. The objects stored in the array may
+   *         be Strings, Doubles, or null (for the missing value).
    * @exception Exception if a problem occurs while getting the results
    */
-  public Object [] getResult(Instances train, Instances test) 
+  @Override
+  public Object[] getResult(Instances train, Instances test)
     throws Exception {
-    
+
     if (m_clusterer == null) {
       throw new Exception("No clusterer has been specified");
     }
-    int addm = (m_additionalMeasures != null) 
-      ? m_additionalMeasures.length 
+    int addm = (m_additionalMeasures != null)
+      ? m_additionalMeasures.length
       : 0;
-    int overall_length = RESULT_SIZE+addm;
+    int overall_length = RESULT_SIZE + addm;
 
     if (m_removeClassColumn && train.classIndex() != -1) {
       // remove the class column from the training and testing data
       Remove r = new Remove();
-      r.setAttributeIndicesArray(new int [] {train.classIndex()});
+      r.setAttributeIndicesArray(new int[] { train.classIndex() });
       r.setInvertSelection(false);
       r.setInputFormat(train);
       train = Filter.useFilter(train, r);
-      
+
       test = Filter.useFilter(test, r);
     }
     train.setClassIndex(-1);
     test.setClassIndex(-1);
-      
 
     ClusterEvaluation eval = new ClusterEvaluation();
 
-    Object [] result = new Object[overall_length];
+    Object[] result = new Object[overall_length];
     long trainTimeStart = System.currentTimeMillis();
     m_clusterer.buildClusterer(train);
     double numClusters = m_clusterer.numberOfClusters();
@@ -444,7 +459,7 @@ public class DensityBasedClustererSplitEvaluator
     long testTimeStart = System.currentTimeMillis();
     eval.evaluateClusterer(test);
     long testTimeElapsed = System.currentTimeMillis() - testTimeStart;
-    //    m_result = eval.toSummaryString();
+    // m_result = eval.toSummaryString();
 
     // The results stored are all per instance -- can be multiplied by the
     // number of instances to get absolute numbers
@@ -454,27 +469,27 @@ public class DensityBasedClustererSplitEvaluator
 
     result[current++] = new Double(eval.getLogLikelihood());
     result[current++] = new Double(numClusters);
-    
+
     // Timing stats
     result[current++] = new Double(trainTimeElapsed / 1000.0);
     result[current++] = new Double(testTimeElapsed / 1000.0);
-    
-    for (int i=0;i<addm;i++) {
+
+    for (int i = 0; i < addm; i++) {
       if (m_doesProduce[i]) {
-	try {
-	  double dv = ((AdditionalMeasureProducer)m_clusterer).
-	    getMeasure(m_additionalMeasures[i]);
-	  Double value = new Double(dv);
-	  
-	  result[current++] = value;
-	} catch (Exception ex) {
-	  System.err.println(ex);
-	}
+        try {
+          double dv = ((AdditionalMeasureProducer) m_clusterer).
+            getMeasure(m_additionalMeasures[i]);
+          Double value = new Double(dv);
+
+          result[current++] = value;
+        } catch (Exception ex) {
+          System.err.println(ex);
+        }
       } else {
-	result[current++] = null;
+        result[current++] = null;
       }
     }
-    
+
     if (current != overall_length) {
       throw new Error("Results didn't fit RESULT_SIZE");
     }
@@ -483,8 +498,9 @@ public class DensityBasedClustererSplitEvaluator
 
   /**
    * Returns the tip text for this property
-   * @return tip text for this property suitable for
-   * displaying in the explorer/experimenter gui
+   * 
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String removeClassColumnTipText() {
     return "Remove the class column (if set) from the data.";
@@ -492,7 +508,7 @@ public class DensityBasedClustererSplitEvaluator
 
   /**
    * Set whether the class column should be removed from the data.
-   *
+   * 
    * @param r true if the class column is to be removed.
    */
   public void setRemoveClassColumn(boolean r) {
@@ -501,17 +517,18 @@ public class DensityBasedClustererSplitEvaluator
 
   /**
    * Get whether the class column is to be removed.
-   *
+   * 
    * @return true if the class column is to be removed.
    */
   public boolean getRemoveClassColumn() {
     return m_removeClassColumn;
   }
-  
+
   /**
    * Returns the tip text for this property
-   * @return tip text for this property suitable for
-   * displaying in the explorer/experimenter gui
+   * 
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String clustererTipText() {
     return "The density based clusterer to use.";
@@ -519,37 +536,36 @@ public class DensityBasedClustererSplitEvaluator
 
   /**
    * Get the value of clusterer
-   *
+   * 
    * @return Value of clusterer.
    */
   public DensityBasedClusterer getClusterer() {
-    
+
     return m_clusterer;
   }
-  
+
   /**
    * Sets the clusterer.
-   *
+   * 
    * @param newClassifier the new clusterer to use.
    */
   public void setClusterer(DensityBasedClusterer newClusterer) {
-    
+
     m_clusterer = newClusterer;
     updateOptions();
   }
 
-
   protected void updateOptions() {
-    
+
     if (m_clusterer instanceof OptionHandler) {
-      m_clustererOptions = Utils.joinOptions(((OptionHandler)m_clusterer)
-					     .getOptions());
+      m_clustererOptions = Utils.joinOptions(((OptionHandler) m_clusterer)
+        .getOptions());
     } else {
       m_clustererOptions = "";
     }
     if (m_clusterer instanceof Serializable) {
       ObjectStreamClass obs = ObjectStreamClass.lookup(m_clusterer
-						       .getClass());
+        .getClass());
       m_clustererVersion = "" + obs.getSerialVersionUID();
     } else {
       m_clustererVersion = "";
@@ -559,25 +575,27 @@ public class DensityBasedClustererSplitEvaluator
   /**
    * Set the Clusterer to use, given it's class name. A new clusterer will be
    * instantiated.
-   *
+   * 
    * @param newClusterer the Classifier class name.
    * @exception Exception if the class name is invalid.
    */
   public void setClustererName(String newClustererName) throws Exception {
 
     try {
-      setClusterer((DensityBasedClusterer)Class.forName(newClustererName)
-		    .newInstance());
+      setClusterer((DensityBasedClusterer) Class.forName(newClustererName)
+        .newInstance());
     } catch (Exception ex) {
       throw new Exception("Can't find Clusterer with class name: "
-			  + newClustererName);
+        + newClustererName);
     }
   }
 
   /**
    * Gets the raw output from the classifier
+   * 
    * @return the raw output from the classifier
    */
+  @Override
   public String getRawResultOutput() {
     StringBuffer result = new StringBuffer();
 
@@ -585,26 +603,26 @@ public class DensityBasedClustererSplitEvaluator
       return "<null> clusterer";
     }
     result.append(toString());
-    result.append("Clustering model: \n"+m_clusterer.toString()+'\n');
+    result.append("Clustering model: \n" + m_clusterer.toString() + '\n');
 
     // append the performance statistics
     if (m_result != null) {
-      //      result.append(m_result);
-      
+      // result.append(m_result);
+
       if (m_doesProduce != null) {
-	for (int i=0;i<m_doesProduce.length;i++) {
-	  if (m_doesProduce[i]) {
-	    try {
-	      double dv = ((AdditionalMeasureProducer)m_clusterer).
-		getMeasure(m_additionalMeasures[i]);
-	      Double value = new Double(dv);
-	      
-	      result.append(m_additionalMeasures[i]+" : "+value+'\n');
-	    } catch (Exception ex) {
-	      System.err.println(ex);
-	    }
-	  } 
-	}
+        for (int i = 0; i < m_doesProduce.length; i++) {
+          if (m_doesProduce[i]) {
+            try {
+              double dv = ((AdditionalMeasureProducer) m_clusterer).
+                getMeasure(m_additionalMeasures[i]);
+              Double value = new Double(dv);
+
+              result.append(m_additionalMeasures[i] + " : " + value + '\n');
+            } catch (Exception ex) {
+              System.err.println(ex);
+            }
+          }
+        }
       }
     }
     return result.toString();
@@ -612,25 +630,27 @@ public class DensityBasedClustererSplitEvaluator
 
   /**
    * Returns a text description of the split evaluator.
-   *
+   * 
    * @return a text description of the split evaluator.
    */
+  @Override
   public String toString() {
 
     String result = "DensityBasedClustererSplitEvaluator: ";
     if (m_clusterer == null) {
       return result + "<null> clusterer";
     }
-    return result + m_clusterer.getClass().getName() + " " 
+    return result + m_clusterer.getClass().getName() + " "
       + m_clustererOptions + "(version " + m_clustererVersion + ")";
   }
-  
+
   /**
    * Returns the revision string.
    * 
-   * @return		the revision
+   * @return the revision
    */
+  @Override
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 5562 $");
+    return RevisionUtils.extract("$Revision: 11198 $");
   }
 }
