@@ -20,9 +20,12 @@
  *
  */
 
-
 package weka.experiment;
 
+import java.util.Enumeration;
+import java.util.Random;
+import java.util.Vector;
+
 import weka.core.AdditionalMeasureProducer;
 import weka.core.Instances;
 import weka.core.Option;
@@ -31,113 +34,142 @@ import weka.core.RevisionHandler;
 import weka.core.RevisionUtils;
 import weka.core.Utils;
 
-import java.util.Enumeration;
-import java.util.Random;
-import java.util.Vector;
-
 /**
- <!-- globalinfo-start -->
- * Tells a sub-ResultProducer to reproduce the current run for varying sized subsamples of the dataset. Normally used with an AveragingResultProducer and CrossValidationResultProducer combo to generate learning curve results. For non-numeric result fields, the first value is used.
+ * <!-- globalinfo-start --> Tells a sub-ResultProducer to reproduce the current
+ * run for varying sized subsamples of the dataset. Normally used with an
+ * AveragingResultProducer and CrossValidationResultProducer combo to generate
+ * learning curve results. For non-numeric result fields, the first value is
+ * used.
  * <p/>
- <!-- globalinfo-end -->
- *
- <!-- options-start -->
- * Valid options are: <p/>
+ * <!-- globalinfo-end -->
  * 
- * <pre> -X &lt;num steps&gt;
+ * <!-- options-start --> Valid options are:
+ * <p/>
+ * 
+ * <pre>
+ * -X &lt;num steps&gt;
  *  The number of steps in the learning rate curve.
- *  (default 10)</pre>
+ *  (default 10)
+ * </pre>
  * 
- * <pre> -W &lt;class name&gt;
+ * <pre>
+ * -W &lt;class name&gt;
  *  The full class name of a ResultProducer.
- *  eg: weka.experiment.CrossValidationResultProducer</pre>
+ *  eg: weka.experiment.CrossValidationResultProducer
+ * </pre>
  * 
- * <pre> 
+ * <pre>
  * Options specific to result producer weka.experiment.AveragingResultProducer:
  * </pre>
  * 
- * <pre> -F &lt;field name&gt;
+ * <pre>
+ * -F &lt;field name&gt;
  *  The name of the field to average over.
- *  (default "Fold")</pre>
+ *  (default "Fold")
+ * </pre>
  * 
- * <pre> -X &lt;num results&gt;
+ * <pre>
+ * -X &lt;num results&gt;
  *  The number of results expected per average.
- *  (default 10)</pre>
+ *  (default 10)
+ * </pre>
  * 
- * <pre> -S
+ * <pre>
+ * -S
  *  Calculate standard deviations.
- *  (default only averages)</pre>
+ *  (default only averages)
+ * </pre>
  * 
- * <pre> -W &lt;class name&gt;
+ * <pre>
+ * -W &lt;class name&gt;
  *  The full class name of a ResultProducer.
- *  eg: weka.experiment.CrossValidationResultProducer</pre>
+ *  eg: weka.experiment.CrossValidationResultProducer
+ * </pre>
  * 
- * <pre> 
+ * <pre>
  * Options specific to result producer weka.experiment.CrossValidationResultProducer:
  * </pre>
  * 
- * <pre> -X &lt;number of folds&gt;
+ * <pre>
+ * -X &lt;number of folds&gt;
  *  The number of folds to use for the cross-validation.
- *  (default 10)</pre>
+ *  (default 10)
+ * </pre>
  * 
- * <pre> -D
- * Save raw split evaluator output.</pre>
+ * <pre>
+ * -D
+ * Save raw split evaluator output.
+ * </pre>
  * 
- * <pre> -O &lt;file/directory name/path&gt;
+ * <pre>
+ * -O &lt;file/directory name/path&gt;
  *  The filename where raw output will be stored.
  *  If a directory name is specified then then individual
  *  outputs will be gzipped, otherwise all output will be
- *  zipped to the named file. Use in conjuction with -D. (default splitEvalutorOut.zip)</pre>
+ *  zipped to the named file. Use in conjuction with -D. (default splitEvalutorOut.zip)
+ * </pre>
  * 
- * <pre> -W &lt;class name&gt;
+ * <pre>
+ * -W &lt;class name&gt;
  *  The full class name of a SplitEvaluator.
- *  eg: weka.experiment.ClassifierSplitEvaluator</pre>
+ *  eg: weka.experiment.ClassifierSplitEvaluator
+ * </pre>
  * 
- * <pre> 
+ * <pre>
  * Options specific to split evaluator weka.experiment.ClassifierSplitEvaluator:
  * </pre>
  * 
- * <pre> -W &lt;class name&gt;
+ * <pre>
+ * -W &lt;class name&gt;
  *  The full class name of the classifier.
- *  eg: weka.classifiers.bayes.NaiveBayes</pre>
+ *  eg: weka.classifiers.bayes.NaiveBayes
+ * </pre>
  * 
- * <pre> -C &lt;index&gt;
+ * <pre>
+ * -C &lt;index&gt;
  *  The index of the class for which IR statistics
- *  are to be output. (default 1)</pre>
+ *  are to be output. (default 1)
+ * </pre>
  * 
- * <pre> -I &lt;index&gt;
+ * <pre>
+ * -I &lt;index&gt;
  *  The index of an attribute to output in the
  *  results. This attribute should identify an
  *  instance in order to know which instances are
  *  in the test set of a cross validation. if 0
- *  no output (default 0).</pre>
+ *  no output (default 0).
+ * </pre>
  * 
- * <pre> -P
+ * <pre>
+ * -P
  *  Add target and prediction columns to the result
- *  for each fold.</pre>
+ *  for each fold.
+ * </pre>
  * 
- * <pre> 
+ * <pre>
  * Options specific to classifier weka.classifiers.rules.ZeroR:
  * </pre>
  * 
- * <pre> -D
+ * <pre>
+ * -D
  *  If set, classifier is run in debug mode and
- *  may output additional info to the console</pre>
+ *  may output additional info to the console
+ * </pre>
+ * 
+ * <!-- options-end -->
  * 
- <!-- options-end -->
- *
  * All options after -- will be passed to the result producer.
  * 
  * @author Len Trigg (trigg@cs.waikato.ac.nz)
- * @version $Revision: 6425 $
+ * @version $Revision: 11198 $
  */
-public class LearningRateResultProducer 
+public class LearningRateResultProducer
   implements ResultListener, ResultProducer, OptionHandler,
-	     AdditionalMeasureProducer, RevisionHandler {
+  AdditionalMeasureProducer, RevisionHandler {
 
   /** for serialization */
   static final long serialVersionUID = -3841159673490861331L;
-  
+
   /** The dataset of interest */
   protected Instances m_Instances;
 
@@ -145,21 +177,20 @@ public class LearningRateResultProducer
   protected ResultListener m_ResultListener = new CSVResultListener();
 
   /** The ResultProducer used to generate results */
-  protected ResultProducer m_ResultProducer
-    = new AveragingResultProducer();
+  protected ResultProducer m_ResultProducer = new AveragingResultProducer();
 
   /** The names of any additional measures to look for in SplitEvaluators */
-  protected String [] m_AdditionalMeasures = null;
+  protected String[] m_AdditionalMeasures = null;
 
-  /** 
-   * The minimum number of instances to use. If this is zero, the first
-   * step will contain m_StepSize instances 
+  /**
+   * The minimum number of instances to use. If this is zero, the first step
+   * will contain m_StepSize instances
    */
   protected int m_LowerSize = 0;
-  
+
   /**
-   * The maximum number of instances to use. -1 indicates no maximum 
-   * (other than the total number of instances)
+   * The maximum number of instances to use. -1 indicates no maximum (other than
+   * the total number of instances)
    */
   protected int m_UpperSize = -1;
 
@@ -174,42 +205,44 @@ public class LearningRateResultProducer
 
   /**
    * Returns a string describing this result producer
-   * @return a description of the result producer suitable for
-   * displaying in the explorer/experimenter gui
+   * 
+   * @return a description of the result producer suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String globalInfo() {
     return "Tells a sub-ResultProducer to reproduce the current run for "
-      +"varying sized subsamples of the dataset. Normally used with "
-      +"an AveragingResultProducer and CrossValidationResultProducer "
-      +"combo to generate learning curve results. For non-numeric "
-      +"result fields, the first value is used.";
+      + "varying sized subsamples of the dataset. Normally used with "
+      + "an AveragingResultProducer and CrossValidationResultProducer "
+      + "combo to generate learning curve results. For non-numeric "
+      + "result fields, the first value is used.";
   }
 
-
   /**
-   * Determines if there are any constraints (imposed by the
-   * destination) on the result columns to be produced by
-   * resultProducers. Null should be returned if there are NO
-   * constraints, otherwise a list of column names should be
+   * Determines if there are any constraints (imposed by the destination) on the
+   * result columns to be produced by resultProducers. Null should be returned
+   * if there are NO constraints, otherwise a list of column names should be
    * returned as an array of Strings.
+   * 
    * @param rp the ResultProducer to which the constraints will apply
-   * @return an array of column names to which resutltProducer's
-   * results will be restricted.
+   * @return an array of column names to which resutltProducer's results will be
+   *         restricted.
    * @throws Exception if constraints can't be determined
    */
-  public String [] determineColumnConstraints(ResultProducer rp) 
+  @Override
+  public String[] determineColumnConstraints(ResultProducer rp)
     throws Exception {
     return null;
   }
 
   /**
-   * Gets the keys for a specified run number. Different run
-   * numbers correspond to different randomizations of the data. Keys
-   * produced should be sent to the current ResultListener
-   *
+   * Gets the keys for a specified run number. Different run numbers correspond
+   * to different randomizations of the data. Keys produced should be sent to
+   * the current ResultListener
+   * 
    * @param run the run number to get keys for.
    * @throws Exception if a problem occurs while getting the keys
    */
+  @Override
   public void doRunKeys(int run) throws Exception {
 
     if (m_ResultProducer == null) {
@@ -233,22 +266,22 @@ public class LearningRateResultProducer
       m_CurrentSize = m_LowerSize;
     }
     while (m_CurrentSize <= m_Instances.numInstances() &&
-           ((m_UpperSize == -1) ||
-            (m_CurrentSize <= m_UpperSize))) {
+      ((m_UpperSize == -1) ||
+      (m_CurrentSize <= m_UpperSize))) {
       m_ResultProducer.doRunKeys(run);
       m_CurrentSize += m_StepSize;
     }
   }
 
-
   /**
-   * Gets the results for a specified run number. Different run
-   * numbers correspond to different randomizations of the data. Results
-   * produced should be sent to the current ResultListener
-   *
+   * Gets the results for a specified run number. Different run numbers
+   * correspond to different randomizations of the data. Results produced should
+   * be sent to the current ResultListener
+   * 
    * @param run the run number to get results for.
    * @throws Exception if a problem occurs while getting the results
    */
+  @Override
   public void doRun(int run) throws Exception {
 
     if (m_ResultProducer == null) {
@@ -264,9 +297,10 @@ public class LearningRateResultProducer
     // Randomize on a copy of the original dataset
     Instances runInstances = new Instances(m_Instances);
     runInstances.randomize(new Random(run));
-    /*if (runInstances.classAttribute().isNominal()) {
-      runInstances.stratify(m_StepSize);
-    }*/
+    /*
+     * if (runInstances.classAttribute().isNominal()) {
+     * runInstances.stratify(m_StepSize); }
+     */
 
     // Tell the resultproducer to send results to us
     m_ResultProducer.setResultListener(this);
@@ -278,23 +312,22 @@ public class LearningRateResultProducer
       m_CurrentSize = m_LowerSize;
     }
     while (m_CurrentSize <= m_Instances.numInstances() &&
-           ((m_UpperSize == -1) ||
-            (m_CurrentSize <= m_UpperSize))) {
-      m_ResultProducer.setInstances(new Instances(runInstances, 0, 
-                                                  m_CurrentSize));
+      ((m_UpperSize == -1) ||
+      (m_CurrentSize <= m_UpperSize))) {
+      m_ResultProducer.setInstances(new Instances(runInstances, 0,
+        m_CurrentSize));
       m_ResultProducer.doRun(run);
       m_CurrentSize += m_StepSize;
     }
   }
 
-  
-  
   /**
    * Prepare for the results to be received.
-   *
+   * 
    * @param rp the ResultProducer that will generate the results
    * @throws Exception if an error occurs during preprocessing.
    */
+  @Override
   public void preProcess(ResultProducer rp) throws Exception {
 
     if (m_ResultListener == null) {
@@ -306,11 +339,12 @@ public class LearningRateResultProducer
   /**
    * Prepare to generate results. The ResultProducer should call
    * preProcess(this) on the ResultListener it is to send results to.
-   *
+   * 
    * @throws Exception if an error occurs during preprocessing.
    */
+  @Override
   public void preProcess() throws Exception {
-    
+
     if (m_ResultProducer == null) {
       throw new Exception("No ResultProducer set");
     }
@@ -318,50 +352,52 @@ public class LearningRateResultProducer
     m_ResultProducer.setResultListener(this);
     m_ResultProducer.preProcess();
   }
-  
+
   /**
-   * When this method is called, it indicates that no more results
-   * will be sent that need to be grouped together in any way.
-   *
+   * When this method is called, it indicates that no more results will be sent
+   * that need to be grouped together in any way.
+   * 
    * @param rp the ResultProducer that generated the results
    * @throws Exception if an error occurs
    */
+  @Override
   public void postProcess(ResultProducer rp) throws Exception {
 
     m_ResultListener.postProcess(this);
   }
 
   /**
-   * When this method is called, it indicates that no more requests to
-   * generate results for the current experiment will be sent. The
-   * ResultProducer should call preProcess(this) on the
-   * ResultListener it is to send results to.
-   *
+   * When this method is called, it indicates that no more requests to generate
+   * results for the current experiment will be sent. The ResultProducer should
+   * call preProcess(this) on the ResultListener it is to send results to.
+   * 
    * @throws Exception if an error occurs
    */
+  @Override
   public void postProcess() throws Exception {
 
     m_ResultProducer.postProcess();
   }
-  
+
   /**
    * Accepts results from a ResultProducer.
-   *
+   * 
    * @param rp the ResultProducer that generated the results
-   * @param key an array of Objects (Strings or Doubles) that uniquely
-   * identify a result for a given ResultProducer with given compatibilityState
-   * @param result the results stored in an array. The objects stored in
-   * the array may be Strings, Doubles, or null (for the missing value).
+   * @param key an array of Objects (Strings or Doubles) that uniquely identify
+   *          a result for a given ResultProducer with given compatibilityState
+   * @param result the results stored in an array. The objects stored in the
+   *          array may be Strings, Doubles, or null (for the missing value).
    * @throws Exception if the result could not be accepted.
    */
-  public void acceptResult(ResultProducer rp, Object [] key, Object [] result)
+  @Override
+  public void acceptResult(ResultProducer rp, Object[] key, Object[] result)
     throws Exception {
 
     if (m_ResultProducer != rp) {
       throw new Error("Unrecognized ResultProducer sending results!!");
     }
     // Add in current step as key field
-    Object [] newKey = new Object [key.length + 1];
+    Object[] newKey = new Object[key.length + 1];
     System.arraycopy(key, 0, newKey, 0, key.length);
     newKey[key.length] = new String("" + m_CurrentSize);
     // Pass on to result listener
@@ -369,24 +405,23 @@ public class LearningRateResultProducer
   }
 
   /**
-   * Determines whether the results for a specified key must be
-   * generated.
-   *
+   * Determines whether the results for a specified key must be generated.
+   * 
    * @param rp the ResultProducer wanting to generate the results
-   * @param key an array of Objects (Strings or Doubles) that uniquely
-   * identify a result for a given ResultProducer with given compatibilityState
+   * @param key an array of Objects (Strings or Doubles) that uniquely identify
+   *          a result for a given ResultProducer with given compatibilityState
    * @return true if the result should be generated
-   * @throws Exception if it could not be determined if the result 
-   * is needed.
+   * @throws Exception if it could not be determined if the result is needed.
    */
-  public boolean isResultRequired(ResultProducer rp, Object [] key) 
+  @Override
+  public boolean isResultRequired(ResultProducer rp, Object[] key)
     throws Exception {
 
     if (m_ResultProducer != rp) {
       throw new Error("Unrecognized ResultProducer sending results!!");
     }
     // Add in current step as key field
-    Object [] newKey = new Object [key.length + 1];
+    Object[] newKey = new Object[key.length + 1];
     System.arraycopy(key, 0, newKey, 0, key.length);
     newKey[key.length] = new String("" + m_CurrentSize);
     // Pass on request to result listener
@@ -395,14 +430,15 @@ public class LearningRateResultProducer
 
   /**
    * Gets the names of each of the columns produced for a single run.
-   *
+   * 
    * @return an array containing the name of each column
    * @throws Exception if key names cannot be generated
    */
-  public String [] getKeyNames() throws Exception {
+  @Override
+  public String[] getKeyNames() throws Exception {
 
-    String [] keyNames = m_ResultProducer.getKeyNames();
-    String [] newKeyNames = new String [keyNames.length + 1];
+    String[] keyNames = m_ResultProducer.getKeyNames();
+    String[] newKeyNames = new String[keyNames.length + 1];
     System.arraycopy(keyNames, 0, newKeyNames, 0, keyNames.length);
     // Think of a better name for this key field
     newKeyNames[keyNames.length] = STEP_FIELD_NAME;
@@ -410,67 +446,69 @@ public class LearningRateResultProducer
   }
 
   /**
-   * Gets the data types of each of the columns produced for a single run.
-   * This method should really be static.
-   *
-   * @return an array containing objects of the type of each column. The 
-   * objects should be Strings, or Doubles.
-   * @throws Exception if the key types could not be determined (perhaps
-   * because of a problem from a nested sub-resultproducer)
+   * Gets the data types of each of the columns produced for a single run. This
+   * method should really be static.
+   * 
+   * @return an array containing objects of the type of each column. The objects
+   *         should be Strings, or Doubles.
+   * @throws Exception if the key types could not be determined (perhaps because
+   *           of a problem from a nested sub-resultproducer)
    */
-  public Object [] getKeyTypes() throws Exception {
+  @Override
+  public Object[] getKeyTypes() throws Exception {
 
-    Object [] keyTypes = m_ResultProducer.getKeyTypes();
-    Object [] newKeyTypes = new Object [keyTypes.length + 1];
+    Object[] keyTypes = m_ResultProducer.getKeyTypes();
+    Object[] newKeyTypes = new Object[keyTypes.length + 1];
     System.arraycopy(keyTypes, 0, newKeyTypes, 0, keyTypes.length);
     newKeyTypes[keyTypes.length] = "";
     return newKeyTypes;
   }
 
   /**
-   * Gets the names of each of the columns produced for a single run.
-   * A new result field is added for the number of results used to
-   * produce each average.
-   * If only averages are being produced the names are not altered, if
-   * standard deviations are produced then "Dev_" and "Avg_" are prepended
-   * to each result deviation and average field respectively.
-   *
+   * Gets the names of each of the columns produced for a single run. A new
+   * result field is added for the number of results used to produce each
+   * average. If only averages are being produced the names are not altered, if
+   * standard deviations are produced then "Dev_" and "Avg_" are prepended to
+   * each result deviation and average field respectively.
+   * 
    * @return an array containing the name of each column
    * @throws Exception if the result names could not be determined (perhaps
-   * because of a problem from a nested sub-resultproducer)
+   *           because of a problem from a nested sub-resultproducer)
    */
-  public String [] getResultNames() throws Exception {
+  @Override
+  public String[] getResultNames() throws Exception {
 
     return m_ResultProducer.getResultNames();
   }
 
   /**
    * Gets the data types of each of the columns produced for a single run.
-   *
-   * @return an array containing objects of the type of each column. The 
-   * objects should be Strings, or Doubles.
+   * 
+   * @return an array containing objects of the type of each column. The objects
+   *         should be Strings, or Doubles.
    * @throws Exception if the result types could not be determined (perhaps
-   * because of a problem from a nested sub-resultproducer)
+   *           because of a problem from a nested sub-resultproducer)
    */
-  public Object [] getResultTypes() throws Exception {
+  @Override
+  public Object[] getResultTypes() throws Exception {
 
     return m_ResultProducer.getResultTypes();
   }
 
   /**
-   * Gets a description of the internal settings of the result
-   * producer, sufficient for distinguishing a ResultProducer
-   * instance from another with different settings (ignoring
-   * those settings set through this interface). For example,
-   * a cross-validation ResultProducer may have a setting for the
-   * number of folds. For a given state, the results produced should
-   * be compatible. Typically if a ResultProducer is an OptionHandler,
-   * this string will represent the command line arguments required
-   * to set the ResultProducer to that state.
-   *
-   * @return the description of the ResultProducer state, or null
-   * if no state is defined
+   * Gets a description of the internal settings of the result producer,
+   * sufficient for distinguishing a ResultProducer instance from another with
+   * different settings (ignoring those settings set through this interface).
+   * For example, a cross-validation ResultProducer may have a setting for the
+   * number of folds. For a given state, the results produced should be
+   * compatible. Typically if a ResultProducer is an OptionHandler, this string
+   * will represent the command line arguments required to set the
+   * ResultProducer to that state.
+   * 
+   * @return the description of the ResultProducer state, or null if no state is
+   *         defined
    */
+  @Override
   public String getCompatibilityState() {
 
     String result = " ";
@@ -480,142 +518,174 @@ public class LearningRateResultProducer
       result += "<null ResultProducer>";
     } else {
       result += "-W " + m_ResultProducer.getClass().getName();
-      result  += " -- " + m_ResultProducer.getCompatibilityState();
+      result += " -- " + m_ResultProducer.getCompatibilityState();
     }
-    
+
     return result.trim();
   }
 
-
   /**
    * Returns an enumeration describing the available options..
-   *
+   * 
    * @return an enumeration of all the available options.
    */
+  @Override
   public Enumeration listOptions() {
 
     Vector newVector = new Vector(2);
 
     newVector.addElement(new Option(
-	     "\tThe number of steps in the learning rate curve.\n"
-	      +"\t(default 10)", 
-	     "X", 1, 
-	     "-X <num steps>"));
+      "\tThe number of steps in the learning rate curve.\n"
+        + "\t(default 10)",
+      "X", 1,
+      "-X <num steps>"));
     newVector.addElement(new Option(
-	     "\tThe full class name of a ResultProducer.\n"
-	      +"\teg: weka.experiment.CrossValidationResultProducer", 
-	     "W", 1, 
-	     "-W <class name>"));
+      "\tThe full class name of a ResultProducer.\n"
+        + "\teg: weka.experiment.CrossValidationResultProducer",
+      "W", 1,
+      "-W <class name>"));
 
     if ((m_ResultProducer != null) &&
-	(m_ResultProducer instanceof OptionHandler)) {
+      (m_ResultProducer instanceof OptionHandler)) {
       newVector.addElement(new Option(
-	     "",
-	     "", 0, "\nOptions specific to result producer "
-	     + m_ResultProducer.getClass().getName() + ":"));
-      Enumeration enu = ((OptionHandler)m_ResultProducer).listOptions();
+        "",
+        "", 0, "\nOptions specific to result producer "
+          + m_ResultProducer.getClass().getName() + ":"));
+      Enumeration enu = ((OptionHandler) m_ResultProducer).listOptions();
       while (enu.hasMoreElements()) {
-	newVector.addElement(enu.nextElement());
+        newVector.addElement(enu.nextElement());
       }
     }
     return newVector.elements();
   }
 
   /**
-   * Parses a given list of options. <p/>
-   *
-   <!-- options-start -->
-   * Valid options are: <p/>
+   * Parses a given list of options.
+   * <p/>
    * 
-   * <pre> -X &lt;num steps&gt;
+   * <!-- options-start --> Valid options are:
+   * <p/>
+   * 
+   * <pre>
+   * -X &lt;num steps&gt;
    *  The number of steps in the learning rate curve.
-   *  (default 10)</pre>
+   *  (default 10)
+   * </pre>
    * 
-   * <pre> -W &lt;class name&gt;
+   * <pre>
+   * -W &lt;class name&gt;
    *  The full class name of a ResultProducer.
-   *  eg: weka.experiment.CrossValidationResultProducer</pre>
+   *  eg: weka.experiment.CrossValidationResultProducer
+   * </pre>
    * 
-   * <pre> 
+   * <pre>
    * Options specific to result producer weka.experiment.AveragingResultProducer:
    * </pre>
    * 
-   * <pre> -F &lt;field name&gt;
+   * <pre>
+   * -F &lt;field name&gt;
    *  The name of the field to average over.
-   *  (default "Fold")</pre>
+   *  (default "Fold")
+   * </pre>
    * 
-   * <pre> -X &lt;num results&gt;
+   * <pre>
+   * -X &lt;num results&gt;
    *  The number of results expected per average.
-   *  (default 10)</pre>
+   *  (default 10)
+   * </pre>
    * 
-   * <pre> -S
+   * <pre>
+   * -S
    *  Calculate standard deviations.
-   *  (default only averages)</pre>
+   *  (default only averages)
+   * </pre>
    * 
-   * <pre> -W &lt;class name&gt;
+   * <pre>
+   * -W &lt;class name&gt;
    *  The full class name of a ResultProducer.
-   *  eg: weka.experiment.CrossValidationResultProducer</pre>
+   *  eg: weka.experiment.CrossValidationResultProducer
+   * </pre>
    * 
-   * <pre> 
+   * <pre>
    * Options specific to result producer weka.experiment.CrossValidationResultProducer:
    * </pre>
    * 
-   * <pre> -X &lt;number of folds&gt;
+   * <pre>
+   * -X &lt;number of folds&gt;
    *  The number of folds to use for the cross-validation.
-   *  (default 10)</pre>
+   *  (default 10)
+   * </pre>
    * 
-   * <pre> -D
-   * Save raw split evaluator output.</pre>
+   * <pre>
+   * -D
+   * Save raw split evaluator output.
+   * </pre>
    * 
-   * <pre> -O &lt;file/directory name/path&gt;
+   * <pre>
+   * -O &lt;file/directory name/path&gt;
    *  The filename where raw output will be stored.
    *  If a directory name is specified then then individual
    *  outputs will be gzipped, otherwise all output will be
-   *  zipped to the named file. Use in conjuction with -D. (default splitEvalutorOut.zip)</pre>
+   *  zipped to the named file. Use in conjuction with -D. (default splitEvalutorOut.zip)
+   * </pre>
    * 
-   * <pre> -W &lt;class name&gt;
+   * <pre>
+   * -W &lt;class name&gt;
    *  The full class name of a SplitEvaluator.
-   *  eg: weka.experiment.ClassifierSplitEvaluator</pre>
+   *  eg: weka.experiment.ClassifierSplitEvaluator
+   * </pre>
    * 
-   * <pre> 
+   * <pre>
    * Options specific to split evaluator weka.experiment.ClassifierSplitEvaluator:
    * </pre>
    * 
-   * <pre> -W &lt;class name&gt;
+   * <pre>
+   * -W &lt;class name&gt;
    *  The full class name of the classifier.
-   *  eg: weka.classifiers.bayes.NaiveBayes</pre>
+   *  eg: weka.classifiers.bayes.NaiveBayes
+   * </pre>
    * 
-   * <pre> -C &lt;index&gt;
+   * <pre>
+   * -C &lt;index&gt;
    *  The index of the class for which IR statistics
-   *  are to be output. (default 1)</pre>
+   *  are to be output. (default 1)
+   * </pre>
    * 
-   * <pre> -I &lt;index&gt;
+   * <pre>
+   * -I &lt;index&gt;
    *  The index of an attribute to output in the
    *  results. This attribute should identify an
    *  instance in order to know which instances are
    *  in the test set of a cross validation. if 0
-   *  no output (default 0).</pre>
+   *  no output (default 0).
+   * </pre>
    * 
-   * <pre> -P
+   * <pre>
+   * -P
    *  Add target and prediction columns to the result
-   *  for each fold.</pre>
+   *  for each fold.
+   * </pre>
    * 
-   * <pre> 
+   * <pre>
    * Options specific to classifier weka.classifiers.rules.ZeroR:
    * </pre>
    * 
-   * <pre> -D
+   * <pre>
+   * -D
    *  If set, classifier is run in debug mode and
-   *  may output additional info to the console</pre>
+   *  may output additional info to the console
+   * </pre>
+   * 
+   * <!-- options-end -->
    * 
-   <!-- options-end -->
-   *
    * All options after -- will be passed to the result producer.
-   *
+   * 
    * @param options the list of options as an array of strings
    * @throws Exception if an option is not supported
    */
+  @Override
   public void setOptions(String[] options) throws Exception {
-    
+
     String stepSize = Utils.getOption('S', options);
     if (stepSize.length() != 0) {
       setStepSize(Integer.parseInt(stepSize));
@@ -629,7 +699,7 @@ public class LearningRateResultProducer
     } else {
       setLowerSize(0);
     }
-    
+
     String upperSize = Utils.getOption('U', options);
     if (upperSize.length() != 0) {
       setUpperSize(Integer.parseInt(upperSize));
@@ -638,37 +708,37 @@ public class LearningRateResultProducer
     }
 
     String rpName = Utils.getOption('W', options);
-    if (rpName.length() == 0) {
-      throw new Exception("A ResultProducer must be specified with"
-			  + " the -W option.");
+    if (rpName.length() > 0) {
+
+      // Do it first without options, so if an exception is thrown during
+      // the option setting, listOptions will contain options for the actual
+      // RP.
+      setResultProducer((ResultProducer) Utils.forName(
+        ResultProducer.class,
+        rpName,
+        null));
     }
-    // Do it first without options, so if an exception is thrown during
-    // the option setting, listOptions will contain options for the actual
-    // RP.
-    setResultProducer((ResultProducer)Utils.forName(
-		      ResultProducer.class,
-		      rpName,
-		      null));
     if (getResultProducer() instanceof OptionHandler) {
       ((OptionHandler) getResultProducer())
-	.setOptions(Utils.partitionOptions(options));
+        .setOptions(Utils.partitionOptions(options));
     }
   }
 
   /**
    * Gets the current settings of the result producer.
-   *
+   * 
    * @return an array of strings suitable for passing to setOptions
    */
-  public String [] getOptions() {
+  @Override
+  public String[] getOptions() {
 
-    String [] seOptions = new String [0];
-    if ((m_ResultProducer != null) && 
-	(m_ResultProducer instanceof OptionHandler)) {
-      seOptions = ((OptionHandler)m_ResultProducer).getOptions();
+    String[] seOptions = new String[0];
+    if ((m_ResultProducer != null) &&
+      (m_ResultProducer instanceof OptionHandler)) {
+      seOptions = ((OptionHandler) m_ResultProducer).getOptions();
     }
-    
-    String [] options = new String [seOptions.length + 9];
+
+    String[] options = new String[seOptions.length + 9];
     int current = 0;
 
     options[current++] = "-S";
@@ -683,8 +753,8 @@ public class LearningRateResultProducer
     }
     options[current++] = "--";
 
-    System.arraycopy(seOptions, 0, options, current, 
-		     seOptions.length);
+    System.arraycopy(seOptions, 0, options, current,
+      seOptions.length);
     current += seOptions.length;
     while (current < options.length) {
       options[current++] = "";
@@ -693,36 +763,40 @@ public class LearningRateResultProducer
   }
 
   /**
-   * Set a list of method names for additional measures to look for
-   * in SplitEvaluators. This could contain many measures (of which only a
-   * subset may be produceable by the current resultProducer) if an experiment
-   * is the type that iterates over a set of properties.
+   * Set a list of method names for additional measures to look for in
+   * SplitEvaluators. This could contain many measures (of which only a subset
+   * may be produceable by the current resultProducer) if an experiment is the
+   * type that iterates over a set of properties.
+   * 
    * @param additionalMeasures an array of measure names, null if none
    */
-  public void setAdditionalMeasures(String [] additionalMeasures) {
+  @Override
+  public void setAdditionalMeasures(String[] additionalMeasures) {
     m_AdditionalMeasures = additionalMeasures;
 
     if (m_ResultProducer != null) {
       System.err.println("LearningRateResultProducer: setting additional "
-			 +"measures for "
-			 +"ResultProducer");
+        + "measures for "
+        + "ResultProducer");
       m_ResultProducer.setAdditionalMeasures(m_AdditionalMeasures);
     }
   }
 
   /**
-   * Returns an enumeration of any additional measure names that might be
-   * in the result producer
+   * Returns an enumeration of any additional measure names that might be in the
+   * result producer
+   * 
    * @return an enumeration of the measure names
    */
+  @Override
   public Enumeration enumerateMeasures() {
     Vector newVector = new Vector();
     if (m_ResultProducer instanceof AdditionalMeasureProducer) {
-      Enumeration en = ((AdditionalMeasureProducer)m_ResultProducer).
-	enumerateMeasures();
+      Enumeration en = ((AdditionalMeasureProducer) m_ResultProducer).
+        enumerateMeasures();
       while (en.hasMoreElements()) {
-	String mname = (String)en.nextElement();
-	newVector.addElement(mname);
+        String mname = (String) en.nextElement();
+        newVector.addElement(mname);
       }
     }
     return newVector.elements();
@@ -730,37 +804,40 @@ public class LearningRateResultProducer
 
   /**
    * Returns the value of the named measure
+   * 
    * @param additionalMeasureName the name of the measure to query for its value
    * @return the value of the named measure
    * @throws IllegalArgumentException if the named measure is not supported
    */
+  @Override
   public double getMeasure(String additionalMeasureName) {
     if (m_ResultProducer instanceof AdditionalMeasureProducer) {
-      return ((AdditionalMeasureProducer)m_ResultProducer).
-	getMeasure(additionalMeasureName);
+      return ((AdditionalMeasureProducer) m_ResultProducer).
+        getMeasure(additionalMeasureName);
     } else {
       throw new IllegalArgumentException("LearningRateResultProducer: "
-			  +"Can't return value for : "+additionalMeasureName
-			  +". "+m_ResultProducer.getClass().getName()+" "
-			  +"is not an AdditionalMeasureProducer");
+        + "Can't return value for : " + additionalMeasureName
+        + ". " + m_ResultProducer.getClass().getName() + " "
+        + "is not an AdditionalMeasureProducer");
     }
   }
 
   /**
    * Sets the dataset that results will be obtained for.
-   *
+   * 
    * @param instances a value of type 'Instances'.
    */
+  @Override
   public void setInstances(Instances instances) {
-    
+
     m_Instances = instances;
   }
 
-
   /**
    * Returns the tip text for this property
-   * @return tip text for this property suitable for
-   * displaying in the explorer/experimenter gui
+   * 
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String lowerSizeTipText() {
     return "Set the minmum number of instances in a dataset. Setting zero "
@@ -770,29 +847,29 @@ public class LearningRateResultProducer
 
   /**
    * Get the value of LowerSize.
-   *
+   * 
    * @return Value of LowerSize.
    */
   public int getLowerSize() {
-    
+
     return m_LowerSize;
   }
-  
+
   /**
    * Set the value of LowerSize.
-   *
-   * @param newLowerSize Value to assign to
-   * LowerSize.
+   * 
+   * @param newLowerSize Value to assign to LowerSize.
    */
   public void setLowerSize(int newLowerSize) {
-    
+
     m_LowerSize = newLowerSize;
   }
 
   /**
    * Returns the tip text for this property
-   * @return tip text for this property suitable for
-   * displaying in the explorer/experimenter gui
+   * 
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String upperSizeTipText() {
     return "Set the maximum number of instances in a dataset. Setting -1 "
@@ -802,30 +879,29 @@ public class LearningRateResultProducer
 
   /**
    * Get the value of UpperSize.
-   *
+   * 
    * @return Value of UpperSize.
    */
   public int getUpperSize() {
-    
+
     return m_UpperSize;
   }
-  
+
   /**
    * Set the value of UpperSize.
-   *
-   * @param newUpperSize Value to assign to
-   * UpperSize.
+   * 
+   * @param newUpperSize Value to assign to UpperSize.
    */
   public void setUpperSize(int newUpperSize) {
-    
+
     m_UpperSize = newUpperSize;
   }
 
-
   /**
    * Returns the tip text for this property
-   * @return tip text for this property suitable for
-   * displaying in the explorer/experimenter gui
+   * 
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String stepSizeTipText() {
     return "Set the number of instances to add at each step.";
@@ -833,39 +909,40 @@ public class LearningRateResultProducer
 
   /**
    * Get the value of StepSize.
-   *
+   * 
    * @return Value of StepSize.
    */
   public int getStepSize() {
-    
+
     return m_StepSize;
   }
-  
+
   /**
    * Set the value of StepSize.
-   *
-   * @param newStepSize Value to assign to
-   * StepSize.
+   * 
+   * @param newStepSize Value to assign to StepSize.
    */
   public void setStepSize(int newStepSize) {
-    
+
     m_StepSize = newStepSize;
   }
 
   /**
    * Sets the object to send results of each run to.
-   *
+   * 
    * @param listener a value of type 'ResultListener'
    */
+  @Override
   public void setResultListener(ResultListener listener) {
 
     m_ResultListener = listener;
   }
-  
+
   /**
    * Returns the tip text for this property
-   * @return tip text for this property suitable for
-   * displaying in the explorer/experimenter gui
+   * 
+   * @return tip text for this property suitable for displaying in the
+   *         explorer/experimenter gui
    */
   public String resultProducerTipText() {
     return "Set the resultProducer for which learning rate results should be "
@@ -874,17 +951,17 @@ public class LearningRateResultProducer
 
   /**
    * Get the ResultProducer.
-   *
+   * 
    * @return the ResultProducer.
    */
   public ResultProducer getResultProducer() {
-    
+
     return m_ResultProducer;
   }
-  
+
   /**
    * Set the ResultProducer.
-   *
+   * 
    * @param newResultProducer new ResultProducer to use.
    */
   public void setResultProducer(ResultProducer newResultProducer) {
@@ -895,9 +972,10 @@ public class LearningRateResultProducer
 
   /**
    * Gets a text descrption of the result producer.
-   *
+   * 
    * @return a text description of the result producer.
    */
+  @Override
   public String toString() {
 
     String result = "LearningRateResultProducer: ";
@@ -913,9 +991,10 @@ public class LearningRateResultProducer
   /**
    * Returns the revision string.
    * 
-   * @return		the revision
+   * @return the revision
    */
+  @Override
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 6425 $");
+    return RevisionUtils.extract("$Revision: 11198 $");
   }
 } // LearningRateResultProducer
