@@ -82,7 +82,7 @@ import java.util.Vector;
  <!-- options-end -->
  *
  * @author Eibe Frank (eibe@cs.waikato.ac.nz) 
- * @version $Revision: 1.8 $ 
+ * @version $Revision: 8094 $ 
  */
 public class NominalToBinary 
   extends Filter 
@@ -99,6 +99,9 @@ public class NominalToBinary
 
   /** Are all values transformed into new attributes? */
   private boolean m_TransformAll = false;
+  
+  /** Whether we need to transform at all */
+  private boolean m_needToTransform = false;
 
   /**
    * Returns a string describing this filter
@@ -148,6 +151,7 @@ public class NominalToBinary
    */
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
+    result.disableAll();
 
     // attributes
     result.enableAllAttributes();
@@ -456,6 +460,20 @@ public class NominalToBinary
     FastVector vals;
 
     // Compute new attributes
+    m_needToTransform = false;
+    for (int i = 0; i < getInputFormat().numAttributes(); i++) {
+      Attribute att = getInputFormat().attribute(i);
+      if (att.isNominal() && i != getInputFormat().classIndex() && 
+          (att.numValues() > 2 || m_TransformAll || m_Numeric)) {
+        m_needToTransform = true;
+        break;
+      }
+    }
+    
+    if (!m_needToTransform) {
+      setOutputFormat(getInputFormat());
+      return;
+    }
 
     newClassIndex = getInputFormat().classIndex();
     newAtts = new FastVector();
@@ -517,6 +535,20 @@ public class NominalToBinary
     FastVector vals;
 
     // Compute new attributes
+    
+    m_needToTransform = false;
+    for (int i = 0; i < getInputFormat().numAttributes(); i++) {
+      Attribute att = getInputFormat().attribute(i);
+      if (att.isNominal() && (att.numValues() > 2 || m_Numeric || m_TransformAll)) {
+        m_needToTransform = true;
+        break;
+      }
+    }
+    
+    if (!m_needToTransform) {
+      setOutputFormat(getInputFormat());
+      return;
+    }
 
     newClassIndex = getInputFormat().classIndex();
     newAtts = new FastVector();
@@ -565,6 +597,11 @@ public class NominalToBinary
    * @param instance the instance to convert
    */
   private void convertInstanceNominal(Instance instance) {
+    
+    if (!m_needToTransform) {
+      push(instance);
+      return;
+    }
 
     double [] vals = new double [outputFormatPeek().numAttributes()];
     int attSoFar = 0;
@@ -615,6 +652,11 @@ public class NominalToBinary
    * @param instance the instance to convert
    */
   private void convertInstanceNumeric(Instance instance) {
+    
+    if (!m_needToTransform) {
+      push(instance);
+      return;
+    }
 
     double [] vals = new double [outputFormatPeek().numAttributes()];
     int attSoFar = 0;
@@ -661,7 +703,7 @@ public class NominalToBinary
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.8 $");
+    return RevisionUtils.extract("$Revision: 8094 $");
   }
 
   /**
