@@ -101,7 +101,7 @@ import java.util.Vector;
  *
  * @author  Dale Fletcher (dale at cs dot waikato dot ac dot nz)
  * @author  fracpete (fracpete at waikato dot ac dot nz)
- * @version $Revision: 1.3 $
+ * @version $Revision: 9529 $
  */
 public class InterquartileRange
   extends SimpleBatchFilter {
@@ -576,10 +576,10 @@ public class InterquartileRange
    */
   public Capabilities getCapabilities() {
     Capabilities result = super.getCapabilities();
+    result.disableAll();
 
     // attributes
     result.enableAllAttributes();
-    result.enable(Capability.MISSING_VALUES);
     
     // class
     result.enableAllClasses();
@@ -782,7 +782,7 @@ public class InterquartileRange
       if (m_AttributeIndices[i] == NON_NUMERIC)
 	continue;
 
-      result = isOutlier(inst, m_AttributeIndices[i]);
+      result = isOutlier(inst, i);
       
       if (result)
 	break;
@@ -827,7 +827,7 @@ public class InterquartileRange
       if (m_AttributeIndices[i] == NON_NUMERIC)
 	continue;
       
-      result = isExtremeValue(inst, m_AttributeIndices[i]);
+      result = isExtremeValue(inst, i);
       
       if (result)
 	break;
@@ -944,7 +944,7 @@ public class InterquartileRange
    * @return		the revision
    */
   public String getRevision() {
-    return RevisionUtils.extract("$Revision: 1.3 $");
+    return RevisionUtils.extract("$Revision: 9529 $");
   }
 
   /**
