@@ -46,7 +46,7 @@ import javax.swing.SwingConstants;
  * maintains a list of all connections
  *
  * @author <a href="mailto:mhall@cs.waikato.ac.nz">Mark Hall</a>
- * @version $Revision: 1.8 $
+ * @version $Revision: 7059 $
  */
 public class BeanConnection
   implements Serializable {
@@ -535,14 +535,16 @@ public class BeanConnection
         // have to do the popup thing here
         int menuItemCount = 0;
         JPopupMenu targetConnectionMenu = new JPopupMenu();
-        targetConnectionMenu.insert(new JLabel("Select target",
+        targetConnectionMenu.insert(new JLabel(Messages.getInstance().getString("BeanConnection_DoMetaConnection_TargetConnectionMenu_Insert_Text_First"),
                                                SwingConstants.CENTER),
                                     menuItemCount++);
         for (int i = 0; i < receivers.size(); i++) {
           final BeanInstance tempTarget = 
             (BeanInstance)receivers.elementAt(i);
           String tName = ""+(i+1)+": " 
-            + tempTarget.getBean().getClass().getName();
+          + ((tempTarget.getBean() instanceof BeanCommon) 
+              ? ((BeanCommon)tempTarget.getBean()).getCustomName() 
+              : tempTarget.getBean().getClass().getName());
           JMenuItem targetItem = new JMenuItem(tName);
           targetItem.addActionListener(new ActionListener() {
               public void actionPerformed(ActionEvent e) {
@@ -601,11 +603,11 @@ public class BeanConnection
 	}
 	CONNECTIONS.addElement(this);
       } catch (Exception ex) {
-	System.err.println("[BeanConnection] Unable to connect beans");
+	System.err.println(Messages.getInstance().getString("BeanConnection_Error_Text_First"));
 	ex.printStackTrace();
       }
     } else {
-      System.err.println("[BeanConnection] Unable to connect beans");
+      System.err.println(Messages.getInstance().getString("BeanConnection_Error_Text_Second"));
     }
   }
 
@@ -692,7 +694,7 @@ public class BeanConnection
      try {
        BeanInfo sourceInfo = Introspector.getBeanInfo(bc.getClass());
        if (sourceInfo == null) {
-       System.err.println("[BeanConnection] Error getting bean info, source info is null.");
+       System.err.println(Messages.getInstance().getString("BeanConnection_GetSourceEventSetDescriptor_Error_Text_First"));
        } else {
 	 EventSetDescriptor [] esds = sourceInfo.getEventSetDescriptors();
 	 for (int i = 0; i < esds.length; i++) {
@@ -702,7 +704,7 @@ public class BeanConnection
 	 }
        }
      } catch (Exception ex) {
-       System.err.println("[BeanConnection] Problem retrieving event set descriptor");
+       System.err.println(Messages.getInstance().getString("BeanConnection_GetSourceEventSetDescriptor_Error_Text_Second"));
      }
      return null;
      
