@@ -40,7 +40,7 @@ import java.util.Vector;
  * A bean that evaluates the performance of batch trained classifiers
  *
  * @author <a href="mailto:mhall@cs.waikato.ac.nz">Mark Hall</a>
- * @version $Revision: 4813 $
+ * @version $Revision: 7059 $
  */
 public class ClassifierPerformanceEvaluator 
   extends AbstractEvaluator
@@ -55,13 +55,11 @@ public class ClassifierPerformanceEvaluator
    */
   private transient Evaluation m_eval;
 
-  /**
-   * Holds the classifier to be evaluated
-   */
-  private transient Classifier m_classifier;
-
   private transient Thread m_evaluateThread = null;
   
+  private transient long m_currentBatchIdentifier;
+  private transient int m_setsComplete;
+  
   private Vector m_textListeners = new Vector();
   private Vector m_thresholdListeners = new Vector();
   private Vector m_visualizableErrorListeners = new Vector();
@@ -98,16 +96,16 @@ public class ClassifierPerformanceEvaluator
    * @return a <code>String</code> value
    */
   public String globalInfo() {
-    return "Evaluate the performance of batch trained classifiers.";
+    return Messages.getInstance().getString("ClassifierPerformanceEvaluator_GlobalInfo_Text");
   }
 
   // ----- Stuff for ROC curves
   private boolean m_rocListenersConnected = false;
   // Plottable Instances with predictions appended
-  private Instances m_predInstances = null;
+  private transient Instances m_predInstances = null;
   // Actual predictions
-  private FastVector m_plotShape = null;
-  private FastVector m_plotSize = null;
+  private transient FastVector m_plotShape = null;
+  private transient FastVector m_plotSize = null;
 
   /**
    * Accept a classifier to be evaluated
@@ -122,24 +120,47 @@ public class ClassifierPerformanceEvaluator
       if (m_evaluateThread == null) {
 	m_evaluateThread = new Thread() {
 	    public void run() {
+	      boolean errorOccurred = false;
 //	      final String oldText = m_visual.getText();
+	      Classifier classifier = ce.getClassifier();
 	      try {
-		if (ce.getSetNumber() == 1 /*|| 
-		    ce.getClassifier() != m_classifier */) {
-		  m_eval = new Evaluation(ce.getTestSet().getDataSet());
-		  m_classifier = ce.getClassifier();
-		  m_predInstances = 
-		    weka.gui.explorer.ClassifierPanel.
-		    setUpVisualizableInstances(new Instances(ce.getTestSet().getDataSet()));
-		  m_plotShape = new FastVector();
-		  m_plotSize = new FastVector();
+		//if (ce.getSetNumber() == 1) {
+	        if (ce.getGroupIdentifier() != m_currentBatchIdentifier) {
+                  if (ce.getTrainSet().getDataSet() == null ||
+                      ce.getTrainSet().getDataSet().numInstances() == 0) {
+                    // we have no training set to estimate majority class
+                    // or mean of target from
+                    m_eval = new Evaluation(ce.getTestSet().getDataSet());
+                    m_eval.useNoPriors();
+                  } else {
+                    m_eval = new Evaluation(ce.getTrainSet().getDataSet());
+                  }
+
+//		  m_classifier = ce.getClassifier();
+		  if (m_visualizableErrorListeners.size() > 0) {
+		    m_predInstances = 
+		      weka.gui.explorer.ClassifierPanel.
+		      setUpVisualizableInstances(new Instances(ce.getTestSet().getDataSet()));
+		    m_plotShape = new FastVector();
+		    m_plotSize = new FastVector();
+		  }
+		  
+		  m_currentBatchIdentifier = ce.getGroupIdentifier();
+                  m_setsComplete = 0;
 		}
-		if (ce.getSetNumber() <= ce.getMaxSetNumber()) {
+//		if (ce.getSetNumber() <= ce.getMaxSetNumber()) {
+	        if (m_setsComplete < ce.getMaxSetNumber()) {
+		  if (ce.getTrainSet().getDataSet() != null &&
+                      ce.getTrainSet().getDataSet().numInstances() > 0) {
+                    // set the priors
+                    m_eval.setPriors(ce.getTrainSet().getDataSet());
+                  }
+		  
 //		  m_visual.setText("Evaluating ("+ce.getSetNumber()+")...");
 		  if (m_logger != null) {
 		    m_logger.statusMessage(statusMessagePrefix()
-					   +"Evaluating ("+ce.getSetNumber()
-					   +")...");
+					   + Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_Visual_SetText_Text_First") + ce.getSetNumber()
+					   + Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_Visual_SetText_Text_Second"));
 		  }
 		  m_visual.setAnimated();
 		  /*
@@ -152,25 +173,26 @@ public class ClassifierPerformanceEvaluator
 						m_eval, m_predInstances, m_plotShape,
 						m_plotSize);
 		  }
+		  
+		  m_setsComplete++;
 		}
 		
 		if (ce.getSetNumber() == ce.getMaxSetNumber()) {
                   //		  System.err.println(m_eval.toSummaryString());
 		  // m_resultsString.append(m_eval.toSummaryString());
 		  // m_outText.setText(m_resultsString.toString());
-		  String textTitle = m_classifier.getClass().getName();
+		  String textTitle = classifier.getClass().getName();
 		  String textOptions = "";
-		  if (m_classifier instanceof OptionHandler) {
+		  if (classifier instanceof OptionHandler) {
 	             textOptions = 
-	               Utils.joinOptions(((OptionHandler)m_classifier).getOptions()); 
+	               Utils.joinOptions(((OptionHandler)classifier).getOptions()); 
 		  }
 		  textTitle = 
 		    textTitle.substring(textTitle.lastIndexOf('.')+1,
 					textTitle.length());
-		  String resultT = "=== Evaluation result ===\n\n"
-		    + "Scheme: " + textTitle + "\n"
-		    + ((textOptions.length() > 0) ? "Options: " + textOptions : "")
-		    + "Relation: " + ce.getTestSet().getDataSet().relationName()
+		  String resultT = Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_ResultT_Text_First") + textTitle + "\n"
+		    + ((textOptions.length() > 0) ? Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_ResultT_Text_Second") + textOptions + "\n": "")
+		    + Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_ResultT_Text_Third") + ce.getTestSet().getDataSet().relationName()
 		    + "\n\n" + m_eval.toSummaryString();
                   
                   if (ce.getTestSet().getDataSet().
@@ -201,18 +223,19 @@ public class ClassifierPerformanceEvaluator
                   }
                   
 
-		  if (ce.getTestSet().getDataSet().classAttribute().isNominal()) {
+		  if (ce.getTestSet().getDataSet().classAttribute().isNominal() &&
+		      m_thresholdListeners.size() > 0) {
 		    ThresholdCurve tc = new ThresholdCurve();
 		    Instances result = tc.getCurve(m_eval.predictions(), 0);
 		    result.
 		      setRelationName(ce.getTestSet().getDataSet().relationName());
 		    PlotData2D pd = new PlotData2D(result);
-		    String htmlTitle = "<html><font size=-2>"
+		    String htmlTitle = Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_HtmlTitle_Text_First")
 		      + textTitle;
 		    String newOptions = "";
-		    if (m_classifier instanceof OptionHandler) {
+		    if (classifier instanceof OptionHandler) {
 		      String[] options = 
-		        ((OptionHandler) m_classifier).getOptions();
+		        ((OptionHandler) classifier).getOptions();
 		      if (options.length > 0) {
 		        for (int ii = 0; ii < options.length; ii++) {
 		          if (options[ii].length() == 0) {
@@ -228,14 +251,14 @@ public class ClassifierPerformanceEvaluator
 		      }
 		    }
 		    
-		   htmlTitle += " " + newOptions + "<br>" 
-		      + " (class: "
+		   htmlTitle += " " + newOptions +  
+		      Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_HtmlTitle_Text_Second")
                       +ce.getTestSet().getDataSet().
                         classAttribute().value(0) + ")" 
-                      + "</font></html>";
-		    pd.setPlotName(textTitle + " (class: "
+                      + Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_HtmlTitle_Text_Third");
+		    pd.setPlotName(textTitle + Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_HtmlTitle_Text_Fourth")
 	                      +ce.getTestSet().getDataSet().
-	                        classAttribute().value(0) + ")");
+	                        classAttribute().value(0) + Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_HtmlTitle_Text_Fifth"));
 		    pd.setPlotNameHTML(htmlTitle);
 		    boolean [] connectPoints = 
 		      new boolean [result.numInstances()];
@@ -245,7 +268,7 @@ public class ClassifierPerformanceEvaluator
 		    pd.setConnectPoints(connectPoints);
 		    ThresholdDataEvent rde = 
 		      new ThresholdDataEvent(ClassifierPerformanceEvaluator.this,
-				       pd);
+				       pd, ce.getTestSet().getDataSet().classAttribute());
 		    notifyThresholdListeners(rde);
 		    /*te = new TextEvent(ClassifierPerformanceEvaluator.this,
 				       result.toString(),
@@ -253,29 +276,37 @@ public class ClassifierPerformanceEvaluator
 				       notifyTextListeners(te); */
 		  }
 		  if (m_logger != null) {
-		    m_logger.statusMessage(statusMessagePrefix() + "Finished.");
+		    m_logger.statusMessage(statusMessagePrefix() + Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_StatusMessage_Text_Third"));
 		  }
+
+		  // save memory
+		  m_predInstances = null;
+		  m_plotShape = null;
+		  m_plotSize = null;
 		}
 	      } catch (Exception ex) {
+	        errorOccurred = true;
 	        ClassifierPerformanceEvaluator.this.stop(); // stop all processing
 	        if (m_logger != null) {
-	          m_logger.logMessage("[ClassifierPerformanceEvaluator] "
+	          m_logger.logMessage(Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_LogMessage_Text_First")
 	              + statusMessagePrefix() 
-	              + " problem evaluating classifier. " 
+	              + Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_LogMessage_Text_Second") 
 	              + ex.getMessage());
-	          m_logger.statusMessage(statusMessagePrefix() 
-	              + "ERROR (See log for details)");
 	        }
 		ex.printStackTrace();
 	      } finally {
 //		m_visual.setText(oldText);
 		m_visual.setStatic();
 		m_evaluateThread = null;
-		if (isInterrupted()) {
-		  if (m_logger != null) {
-		    m_logger.logMessage("[" + getCustomName() +"] Evaluation interrupted!");
+				
+		if (m_logger != null) {
+		  if (errorOccurred) {
 		    m_logger.statusMessage(statusMessagePrefix() 
-		        + "INTERRUPTED");
+		        + Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_StatusMessage_Text_Fourth"));
+		  } else if (isInterrupted()) {
+		    m_logger.logMessage(Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_LogMessage_Text_Third") + getCustomName() + Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_LogMessage_Text_Fourth"));
+		    m_logger.statusMessage(statusMessagePrefix() 
+		        + Messages.getInstance().getString("ClassifierPerformanceEvaluator_AcceptClassifier_StatusMessage_Text_Fifth"));
 		  }
 		}
 		block(false);
@@ -305,7 +336,7 @@ public class ClassifierPerformanceEvaluator
   public boolean isBusy() {
     return (m_evaluateThread != null);
   }
-  
+    
   /**
    * Try and stop any action
    */
@@ -372,7 +403,7 @@ public class ClassifierPerformanceEvaluator
       throw new 
 	IllegalArgumentException(request
 
-		    + " not supported (ClassifierPerformanceEvaluator)");
+		    + Messages.getInstance().getString("ClassifierPerformanceEvaluator_PerformRequest_IllegalArgumentException_Text"));
     }
   }
 
