@@ -16,7 +16,7 @@
 
 /*
  *    Startable.java
- *    Copyright (C) 2008 Pentaho Corporation
+ *    Copyright (C) 2008 University of Waikato, Hamilton, New Zealand
  *
  */
 
@@ -27,7 +27,7 @@ package weka.gui.beans;
  * can be launched programatically.
  *
  * @author Mark Hall (mhall{[at]}pentaho{[dot]}org)
- * @version $Revision: 1.1 $
+ * @version $Revision: 6017 $
  * @since 1.0
  */
 public interface Startable {
@@ -38,4 +38,15 @@ public interface Startable {
    * @exception Exception if something goes wrong
    */
   void start() throws Exception;
-}
\ No newline at end of file
+  
+  /**
+   * Gets a string that describes the start action. The
+   * KnowledgeFlow uses this in the popup contextual menu
+   * for the component. The string can be proceeded by
+   * a '$' character to indicate that the component can't
+   * be started at present.
+   * 
+   * @return a string describing the start action.
+   */
+  String getStartMessage();
+}
