@@ -27,13 +27,12 @@ import java.util.Vector;
 
 /**
  * Bean that accepts data sets and produces test sets
- *
+ * 
  * @author <a href="mailto:mhall@cs.waikato.ac.nz">Mark Hall</a>
- * @version $Revision: 7059 $
+ * @version $Revision: 9752 $
  */
-public class TestSetMaker
-  extends AbstractTestSetProducer 
-  implements DataSourceListener, EventConstraints, Serializable {
+public class TestSetMaker extends AbstractTestSetProducer implements
+    DataSourceListener, TrainingSetListener, EventConstraints, Serializable {
 
   /** for serialization */
   private static final long serialVersionUID = -8473882857628061841L;
@@ -41,10 +40,8 @@ public class TestSetMaker
   protected boolean m_receivedStopNotification = false;
 
   public TestSetMaker() {
-     m_visual.loadIcons(BeanVisual.ICON_PATH
-		       +"TestSetMaker.gif",
-		       BeanVisual.ICON_PATH
-		       +"TestSetMaker_animated.gif");
+    m_visual.loadIcons(BeanVisual.ICON_PATH + "TestSetMaker.gif",
+        BeanVisual.ICON_PATH + "TestSetMaker_animated.gif");
     m_visual.setText("TestSetMaker");
   }
 
@@ -53,6 +50,7 @@ public class TestSetMaker
    * 
    * @param name the name to use
    */
+  @Override
   public void setCustomName(String name) {
     m_visual.setText(name);
   }
@@ -62,13 +60,14 @@ public class TestSetMaker
    * 
    * @return the custom name (or the default name)
    */
+  @Override
   public String getCustomName() {
     return m_visual.getText();
   }
 
   /**
    * Global info for this bean
-   *
+   * 
    * @return a <code>String</code> value
    */
   public String globalInfo() {
@@ -77,9 +76,10 @@ public class TestSetMaker
 
   /**
    * Accepts and processes a data set event
-   *
+   * 
    * @param e a <code>DataSetEvent</code> value
    */
+  @Override
   public void acceptDataSet(DataSetEvent e) {
     m_receivedStopNotification = false;
     TestSetEvent tse = new TestSetEvent(this, e.getDataSet());
@@ -88,75 +88,96 @@ public class TestSetMaker
     notifyTestSetProduced(tse);
   }
 
+  @Override
+  public void acceptTrainingSet(TrainingSetEvent e) {
+    m_receivedStopNotification = false;
+    TestSetEvent tse = new TestSetEvent(this, e.getTrainingSet());
+    tse.m_setNumber = 1;
+    tse.m_maxSetNumber = 1;
+    notifyTestSetProduced(tse);
+  }
+
   /**
    * Tells all listeners that a test set is available
-   *
+   * 
    * @param tse a <code>TestSetEvent</code> value
    */
   protected void notifyTestSetProduced(TestSetEvent tse) {
     Vector l;
     synchronized (this) {
-      l = (Vector)m_listeners.clone();
+      l = (Vector) m_listeners.clone();
     }
     if (l.size() > 0) {
-      for(int i = 0; i < l.size(); i++) {
+      for (int i = 0; i < l.size(); i++) {
         if (m_receivedStopNotification) {
           if (m_logger != null) {
-            m_logger.logMessage(Messages.getInstance().getString("TestSetMaker_NotifyTestSetProduced_LogMessage_Text_First")
-                + statusMessagePrefix() + Messages.getInstance().getString("TestSetMaker_NotifyTestSetProduced_LogMessage_Text_Second"));
-            m_logger.statusMessage(statusMessagePrefix()
-                + Messages.getInstance().getString("TestSetMaker_NotifyTestSetProduced_LogMessage_Text_Third"));
+            m_logger
+                .logMessage(Messages.getInstance().getString(
+                    "TestSetMaker_NotifyTestSetProduced_LogMessage_Text_First")
+                    + statusMessagePrefix()
+                    + Messages
+                        .getInstance()
+                        .getString(
+                            "TestSetMaker_NotifyTestSetProduced_LogMessage_Text_Second"));
+            m_logger
+                .statusMessage(statusMessagePrefix()
+                    + Messages
+                        .getInstance()
+                        .getString(
+                            "TestSetMaker_NotifyTestSetProduced_LogMessage_Text_Third"));
           }
           m_receivedStopNotification = false;
           break;
         }
-	((TestSetListener)l.elementAt(i)).acceptTestSet(tse);
+        ((TestSetListener) l.elementAt(i)).acceptTestSet(tse);
       }
     }
   }
 
+  @Override
   public void stop() {
     // do something
     m_receivedStopNotification = true;
 
     // tell the listenee (upstream bean) to stop
     if (m_listenee instanceof BeanCommon) {
-      ((BeanCommon)m_listenee).stop();
+      ((BeanCommon) m_listenee).stop();
     }
   }
-  
+
   /**
-   * Returns true if. at this time, the bean is busy with some
-   * (i.e. perhaps a worker thread is performing some calculation).
+   * Returns true if. at this time, the bean is busy with some (i.e. perhaps a
+   * worker thread is performing some calculation).
    * 
    * @return true if the bean is busy.
    */
+  @Override
   public boolean isBusy() {
     return false;
   }
 
   /**
-   * Returns true, if at the current time, the named event could
-   * be generated. Assumes that supplied event names are names of
-   * events that could be generated by this bean.
-   *
+   * Returns true, if at the current time, the named event could be generated.
+   * Assumes that supplied event names are names of events that could be
+   * generated by this bean.
+   * 
    * @param eventName the name of the event in question
-   * @return true if the named event could be generated at this point in
-   * time
+   * @return true if the named event could be generated at this point in time
    */
+  @Override
   public boolean eventGeneratable(String eventName) {
     if (m_listenee == null) {
       return false;
     }
 
     if (m_listenee instanceof EventConstraints) {
-      if (!((EventConstraints)m_listenee).eventGeneratable("dataSet")) {
-	return false;
+      if (!((EventConstraints) m_listenee).eventGeneratable("dataSet")) {
+        return false;
       }
     }
     return true;
   }
-  
+
   private String statusMessagePrefix() {
     return getCustomName() + "$" + hashCode() + "|";
   }
