@@ -22,6 +22,7 @@
 
 package weka.gui.visualize;
 
+
 import weka.core.FastVector;
 import weka.core.Instances;
 import weka.core.Utils;
@@ -49,7 +50,7 @@ import javax.swing.JPanel;
  *
  * @author Mark Hall (mhall@cs.waikato.ac.nz)
  * @author Malcolm Ware (mfw4@cs.waikato.ac.nz)
- * @version $Revision: 1.16 $
+ * @version $Revision: 7059 $
  */
 public class ClassPanel
   extends JPanel {
@@ -124,6 +125,12 @@ public class ClassPanel
 					new Color(255, 0, 0),
 					new Color(0, 255, 0),
 					Color.white};
+  
+  /**
+   *  if set, it allows this panel to steer away from setting up
+   * a color in the color list that is equal to the background color
+   */
+  protected Color m_backgroundColor = null;
 
   /** Inner Inner class used to create labels for nominal attributes
    * so that there color can be changed.
@@ -175,8 +182,14 @@ public class ClassPanel
 	});
     }
   }
-
+  
   public ClassPanel() {
+    this(null);
+  }
+
+  public ClassPanel(Color background) {
+    m_backgroundColor = background;
+    
     /** Set up some default colours */
     m_colorList = new FastVector(10);
     for (int noa = m_colorList.size(); noa < 10; noa++) {
@@ -276,11 +289,18 @@ public class ClassPanel
 	for (int j=0;j<ija;j++) {
 	  pc = pc.brighter();
 	}
+        if (m_backgroundColor != null) {
+          pc = Plot2D.checkAgainstBackground(pc, m_backgroundColor);
+        }
 	
 	m_colorList.addElement(pc);
       }
     }
   }
+    
+  protected void setDefaultColourList(Color[] list) {
+    m_DefaultColors = list;
+  }
 
   /**
    * Set a list of colours to use for colouring labels
@@ -699,12 +719,11 @@ public class ClassPanel
   public static void main(String [] args) {
     try {
       if (args.length < 1) {
-	System.err.println("Usage : weka.gui.visualize.ClassPanel <dataset> "
-			   +"[class col]");
+	System.err.println(Messages.getInstance().getString("ClassPanel_Main_Error_Text_First"));
 	System.exit(1);
       }
       final javax.swing.JFrame jf = 
-	new javax.swing.JFrame("Weka Explorer: Class");
+	new javax.swing.JFrame(Messages.getInstance().getString("ClassPanel_Main_JFrame_Text"));
       jf.setSize(500,100);
       jf.getContentPane().setLayout(new BorderLayout());
       final ClassPanel p2 = new ClassPanel();
@@ -717,7 +736,7 @@ public class ClassPanel
 	});
 	
       if (args.length >= 1) {
-	System.err.println("Loading instances from " + args[0]);
+	System.err.println(Messages.getInstance().getString("ClassPanel_Main_Error_Text_Second") + args[0]);
 	java.io.Reader r = new java.io.BufferedReader(
 			   new java.io.FileReader(args[0]));
 	Instances i = new Instances(r);
